# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/route/route.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.route import route_components_pb2 as envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2

from envoy.api.v2.route.route_components_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65nvoy/api/v2/route/route.proto\x12\x12\x65nvoy.api.v2.route\x1a)envoy/api/v2/route/route_components.protoBk\n io.envoyproxy.envoy.api.v2.routeB\nRouteProtoP\x01Z9github.com/envoyproxy/go-control-plane/envoy/api/v2/routeP\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.route.route_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n io.envoyproxy.envoy.api.v2.routeB\nRouteProtoP\001Z9github.com/envoyproxy/go-control-plane/envoy/api/v2/route'
# @@protoc_insertion_point(module_scope)
