# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/endpoint/endpoint_components.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import health_check_pb2 as envoy_dot_api_dot_v2_dot_core_dot_health__check__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/envoy/api/v2/endpoint/endpoint_components.proto\x12\x15\x65nvoy.api.v2.endpoint\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a$envoy/api/v2/core/health_check.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xdf\x01\n\x08\x45ndpoint\x12+\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\x12N\n\x13health_check_config\x18\x02 \x01(\x0b\x32\x31.envoy.api.v2.endpoint.Endpoint.HealthCheckConfig\x12\x10\n\x08hostname\x18\x03 \x01(\t\x1a\x44\n\x11HealthCheckConfig\x12\x1d\n\nport_value\x18\x01 \x01(\rB\t\xfa\x42\x06*\x04\x18\xff\xff\x03\x12\x10\n\x08hostname\x18\x02 \x01(\t\"\x9a\x02\n\nLbEndpoint\x12\x33\n\x08\x65ndpoint\x18\x01 \x01(\x0b\x32\x1f.envoy.api.v2.endpoint.EndpointH\x00\x12\x17\n\rendpoint_name\x18\x05 \x01(\tH\x00\x12\x36\n\rhealth_status\x18\x02 \x01(\x0e\x32\x1f.envoy.api.v2.core.HealthStatus\x12-\n\x08metadata\x18\x03 \x01(\x0b\x32\x1b.envoy.api.v2.core.Metadata\x12\x44\n\x15load_balancing_weight\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x42\x11\n\x0fhost_identifier\"\x90\x02\n\x13LocalityLbEndpoints\x12-\n\x08locality\x18\x01 \x01(\x0b\x32\x1b.envoy.api.v2.core.Locality\x12\x37\n\x0clb_endpoints\x18\x02 \x03(\x0b\x32!.envoy.api.v2.endpoint.LbEndpoint\x12\x44\n\x15load_balancing_weight\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12\x1a\n\x08priority\x18\x05 \x01(\rB\x08\xfa\x42\x05*\x03\x18\x80\x01\x12/\n\tproximity\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\xa6\x01\n#io.envoyproxy.envoy.api.v2.endpointB\x17\x45ndpointComponentsProtoP\x01Z<github.com/envoyproxy/go-control-plane/envoy/api/v2/endpoint\xf2\x98\xfe\x8f\x05\x1a\x12\x18\x65nvoy.config.endpoint.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.endpoint.endpoint_components_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.api.v2.endpointB\027EndpointComponentsProtoP\001Z<github.com/envoyproxy/go-control-plane/envoy/api/v2/endpoint\362\230\376\217\005\032\022\030envoy.config.endpoint.v3\272\200\310\321\006\002\020\001'
  _ENDPOINT_HEALTHCHECKCONFIG.fields_by_name['port_value']._options = None
  _ENDPOINT_HEALTHCHECKCONFIG.fields_by_name['port_value']._serialized_options = b'\372B\006*\004\030\377\377\003'
  _LBENDPOINT.fields_by_name['load_balancing_weight']._options = None
  _LBENDPOINT.fields_by_name['load_balancing_weight']._serialized_options = b'\372B\004*\002(\001'
  _LOCALITYLBENDPOINTS.fields_by_name['load_balancing_weight']._options = None
  _LOCALITYLBENDPOINTS.fields_by_name['load_balancing_weight']._serialized_options = b'\372B\004*\002(\001'
  _LOCALITYLBENDPOINTS.fields_by_name['priority']._options = None
  _LOCALITYLBENDPOINTS.fields_by_name['priority']._serialized_options = b'\372B\005*\003\030\200\001'
  _globals['_ENDPOINT']._serialized_start=296
  _globals['_ENDPOINT']._serialized_end=519
  _globals['_ENDPOINT_HEALTHCHECKCONFIG']._serialized_start=451
  _globals['_ENDPOINT_HEALTHCHECKCONFIG']._serialized_end=519
  _globals['_LBENDPOINT']._serialized_start=522
  _globals['_LBENDPOINT']._serialized_end=804
  _globals['_LOCALITYLBENDPOINTS']._serialized_start=807
  _globals['_LOCALITYLBENDPOINTS']._serialized_end=1079
# @@protoc_insertion_point(module_scope)
