# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/core/protocol.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n envoy/api/v2/core/protocol.proto\x12\x11\x65nvoy.api.v2.core\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x14\n\x12TcpProtocolOptions\"L\n\x1bUpstreamHttpProtocolOptions\x12\x10\n\x08\x61uto_sni\x18\x01 \x01(\x08\x12\x1b\n\x13\x61uto_san_validation\x18\x02 \x01(\x08\"\xba\x03\n\x13HttpProtocolOptions\x12/\n\x0cidle_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12:\n\x17max_connection_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12@\n\x11max_headers_count\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12\x36\n\x13max_stream_duration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12l\n\x1fheaders_with_underscores_action\x18\x05 \x01(\x0e\x32\x43.envoy.api.v2.core.HttpProtocolOptions.HeadersWithUnderscoresAction\"N\n\x1cHeadersWithUnderscoresAction\x12\t\n\x05\x41LLOW\x10\x00\x12\x12\n\x0eREJECT_REQUEST\x10\x01\x12\x0f\n\x0b\x44ROP_HEADER\x10\x02\"\x98\x03\n\x14Http1ProtocolOptions\x12\x36\n\x12\x61llow_absolute_url\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x16\n\x0e\x61\x63\x63\x65pt_http_10\x18\x02 \x01(\x08\x12 \n\x18\x64\x65\x66\x61ult_host_for_http_10\x18\x03 \x01(\t\x12R\n\x11header_key_format\x18\x04 \x01(\x0b\x32\x37.envoy.api.v2.core.Http1ProtocolOptions.HeaderKeyFormat\x12\x17\n\x0f\x65nable_trailers\x18\x05 \x01(\x08\x1a\xa0\x01\n\x0fHeaderKeyFormat\x12\x64\n\x11proper_case_words\x18\x01 \x01(\x0b\x32G.envoy.api.v2.core.Http1ProtocolOptions.HeaderKeyFormat.ProperCaseWordsH\x00\x1a\x11\n\x0fProperCaseWordsB\x14\n\rheader_format\x12\x03\xf8\x42\x01\"\xb0\x08\n\x14Http2ProtocolOptions\x12\x36\n\x10hpack_table_size\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12K\n\x16max_concurrent_streams\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\r\xfa\x42\n*\x08\x18\xff\xff\xff\xff\x07(\x01\x12Q\n\x1ainitial_stream_window_size\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0f\xfa\x42\x0c*\n\x18\xff\xff\xff\xff\x07(\xff\xff\x03\x12U\n\x1einitial_connection_window_size\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0f\xfa\x42\x0c*\n\x18\xff\xff\xff\xff\x07(\xff\xff\x03\x12\x15\n\rallow_connect\x18\x05 \x01(\x08\x12\x16\n\x0e\x61llow_metadata\x18\x06 \x01(\x08\x12\x42\n\x13max_outbound_frames\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12J\n\x1bmax_outbound_control_frames\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12W\n1max_consecutive_inbound_frames_with_empty_payload\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12L\n&max_inbound_priority_frames_per_stream\x18\n \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x63\n4max_inbound_window_update_frames_per_data_frame_sent\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12.\n&stream_error_on_invalid_http_messaging\x18\x0c \x01(\x08\x12]\n\x1a\x63ustom_settings_parameters\x18\r \x03(\x0b\x32\x39.envoy.api.v2.core.Http2ProtocolOptions.SettingsParameter\x1a\x8e\x01\n\x11SettingsParameter\x12\x42\n\nidentifier\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x10\xfa\x42\r*\x06\x18\x80\x80\x04(\x01\x8a\x01\x02\x10\x01\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"^\n\x13GrpcProtocolOptions\x12G\n\x16http2_protocol_options\x18\x01 \x01(\x0b\x32\'.envoy.api.v2.core.Http2ProtocolOptionsB\x90\x01\n\x1fio.envoyproxy.envoy.api.v2.coreB\rProtocolProtoP\x01Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\xf2\x98\xfe\x8f\x05\x16\x12\x14\x65nvoy.config.core.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.core.protocol_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037io.envoyproxy.envoy.api.v2.coreB\rProtocolProtoP\001Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\362\230\376\217\005\026\022\024envoy.config.core.v3\272\200\310\321\006\002\020\001'
  _HTTPPROTOCOLOPTIONS.fields_by_name['max_headers_count']._options = None
  _HTTPPROTOCOLOPTIONS.fields_by_name['max_headers_count']._serialized_options = b'\372B\004*\002(\001'
  _HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT.oneofs_by_name['header_format']._options = None
  _HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT.oneofs_by_name['header_format']._serialized_options = b'\370B\001'
  _HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER.fields_by_name['identifier']._options = None
  _HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER.fields_by_name['identifier']._serialized_options = b'\372B\r*\006\030\200\200\004(\001\212\001\002\020\001'
  _HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER.fields_by_name['value']._options = None
  _HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER.fields_by_name['value']._serialized_options = b'\372B\005\212\001\002\020\001'
  _HTTP2PROTOCOLOPTIONS.fields_by_name['max_concurrent_streams']._options = None
  _HTTP2PROTOCOLOPTIONS.fields_by_name['max_concurrent_streams']._serialized_options = b'\372B\n*\010\030\377\377\377\377\007(\001'
  _HTTP2PROTOCOLOPTIONS.fields_by_name['initial_stream_window_size']._options = None
  _HTTP2PROTOCOLOPTIONS.fields_by_name['initial_stream_window_size']._serialized_options = b'\372B\014*\n\030\377\377\377\377\007(\377\377\003'
  _HTTP2PROTOCOLOPTIONS.fields_by_name['initial_connection_window_size']._options = None
  _HTTP2PROTOCOLOPTIONS.fields_by_name['initial_connection_window_size']._serialized_options = b'\372B\014*\n\030\377\377\377\377\007(\377\377\003'
  _HTTP2PROTOCOLOPTIONS.fields_by_name['max_outbound_frames']._options = None
  _HTTP2PROTOCOLOPTIONS.fields_by_name['max_outbound_frames']._serialized_options = b'\372B\004*\002(\001'
  _HTTP2PROTOCOLOPTIONS.fields_by_name['max_outbound_control_frames']._options = None
  _HTTP2PROTOCOLOPTIONS.fields_by_name['max_outbound_control_frames']._serialized_options = b'\372B\004*\002(\001'
  _HTTP2PROTOCOLOPTIONS.fields_by_name['max_inbound_window_update_frames_per_data_frame_sent']._options = None
  _HTTP2PROTOCOLOPTIONS.fields_by_name['max_inbound_window_update_frames_per_data_frame_sent']._serialized_options = b'\372B\004*\002(\001'
  _globals['_TCPPROTOCOLOPTIONS']._serialized_start=207
  _globals['_TCPPROTOCOLOPTIONS']._serialized_end=227
  _globals['_UPSTREAMHTTPPROTOCOLOPTIONS']._serialized_start=229
  _globals['_UPSTREAMHTTPPROTOCOLOPTIONS']._serialized_end=305
  _globals['_HTTPPROTOCOLOPTIONS']._serialized_start=308
  _globals['_HTTPPROTOCOLOPTIONS']._serialized_end=750
  _globals['_HTTPPROTOCOLOPTIONS_HEADERSWITHUNDERSCORESACTION']._serialized_start=672
  _globals['_HTTPPROTOCOLOPTIONS_HEADERSWITHUNDERSCORESACTION']._serialized_end=750
  _globals['_HTTP1PROTOCOLOPTIONS']._serialized_start=753
  _globals['_HTTP1PROTOCOLOPTIONS']._serialized_end=1161
  _globals['_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT']._serialized_start=1001
  _globals['_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT']._serialized_end=1161
  _globals['_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT_PROPERCASEWORDS']._serialized_start=1122
  _globals['_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT_PROPERCASEWORDS']._serialized_end=1139
  _globals['_HTTP2PROTOCOLOPTIONS']._serialized_start=1164
  _globals['_HTTP2PROTOCOLOPTIONS']._serialized_end=2236
  _globals['_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER']._serialized_start=2094
  _globals['_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER']._serialized_end=2236
  _globals['_GRPCPROTOCOLOPTIONS']._serialized_start=2238
  _globals['_GRPCPROTOCOLOPTIONS']._serialized_end=2332
# @@protoc_insertion_point(module_scope)
