# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/dubbo_proxy/v3/route.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from envoy.type.v3 import range_pb2 as envoy_dot_type_dot_v3_dot_range__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;envoy/extensions/filters/network/dubbo_proxy/v3/route.proto\x12/envoy.extensions.filters.network.dubbo_proxy.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a,envoy/config/route/v3/route_components.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x19\x65nvoy/type/v3/range.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xe9\x01\n\x12RouteConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tinterface\x18\x02 \x01(\t\x12\r\n\x05group\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\x12\x46\n\x06routes\x18\x05 \x03(\x0b\x32\x36.envoy.extensions.filters.network.dubbo_proxy.v3.Route:J\x9a\xc5\x88\x1e\x45\nCenvoy.config.filter.network.dubbo_proxy.v2alpha1.RouteConfiguration\"\xf3\x01\n\x05Route\x12T\n\x05match\x18\x01 \x01(\x0b\x32;.envoy.extensions.filters.network.dubbo_proxy.v3.RouteMatchB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12U\n\x05route\x18\x02 \x01(\x0b\x32<.envoy.extensions.filters.network.dubbo_proxy.v3.RouteActionB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:=\x9a\xc5\x88\x1e\x38\n6envoy.config.filter.network.dubbo_proxy.v2alpha1.Route\"\xd5\x01\n\nRouteMatch\x12L\n\x06method\x18\x01 \x01(\x0b\x32<.envoy.extensions.filters.network.dubbo_proxy.v3.MethodMatch\x12\x35\n\x07headers\x18\x02 \x03(\x0b\x32$.envoy.config.route.v3.HeaderMatcher:B\x9a\xc5\x88\x1e=\n;envoy.config.filter.network.dubbo_proxy.v2alpha1.RouteMatch\"\xfc\x01\n\x0bRouteAction\x12\x11\n\x07\x63luster\x18\x01 \x01(\tH\x00\x12\x43\n\x11weighted_clusters\x18\x02 \x01(\x0b\x32&.envoy.config.route.v3.WeightedClusterH\x00\x12\x36\n\x0emetadata_match\x18\x03 \x01(\x0b\x32\x1e.envoy.config.core.v3.Metadata:C\x9a\xc5\x88\x1e>\n<envoy.config.filter.network.dubbo_proxy.v2alpha1.RouteActionB\x18\n\x11\x63luster_specifier\x12\x03\xf8\x42\x01\"\xd5\x04\n\x0bMethodMatch\x12\x32\n\x04name\x18\x01 \x01(\x0b\x32$.envoy.type.matcher.v3.StringMatcher\x12\x63\n\x0cparams_match\x18\x02 \x03(\x0b\x32M.envoy.extensions.filters.network.dubbo_proxy.v3.MethodMatch.ParamsMatchEntry\x1a\xdc\x01\n\x17ParameterMatchSpecifier\x12\x15\n\x0b\x65xact_match\x18\x03 \x01(\tH\x00\x12\x30\n\x0brange_match\x18\x04 \x01(\x0b\x32\x19.envoy.type.v3.Int64RangeH\x00:[\x9a\xc5\x88\x1eV\nTenvoy.config.filter.network.dubbo_proxy.v2alpha1.MethodMatch.ParameterMatchSpecifierB\x1b\n\x19parameter_match_specifier\x1a\x88\x01\n\x10ParamsMatchEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\x63\n\x05value\x18\x02 \x01(\x0b\x32T.envoy.extensions.filters.network.dubbo_proxy.v3.MethodMatch.ParameterMatchSpecifier:\x02\x38\x01:C\x9a\xc5\x88\x1e>\n<envoy.config.filter.network.dubbo_proxy.v2alpha1.MethodMatch\"\x85\x01\n\x1aMultipleRouteConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12Y\n\x0croute_config\x18\x04 \x03(\x0b\x32\x43.envoy.extensions.filters.network.dubbo_proxy.v3.RouteConfigurationB\xbb\x01\n=io.envoyproxy.envoy.extensions.filters.network.dubbo_proxy.v3B\nRouteProtoP\x01Zdgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/dubbo_proxy/v3;dubbo_proxyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.network.dubbo_proxy.v3.route_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n=io.envoyproxy.envoy.extensions.filters.network.dubbo_proxy.v3B\nRouteProtoP\001Zdgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/dubbo_proxy/v3;dubbo_proxyv3\272\200\310\321\006\002\020\002'
  _ROUTECONFIGURATION._options = None
  _ROUTECONFIGURATION._serialized_options = b'\232\305\210\036E\nCenvoy.config.filter.network.dubbo_proxy.v2alpha1.RouteConfiguration'
  _ROUTE.fields_by_name['match']._options = None
  _ROUTE.fields_by_name['match']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ROUTE.fields_by_name['route']._options = None
  _ROUTE.fields_by_name['route']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ROUTE._options = None
  _ROUTE._serialized_options = b'\232\305\210\0368\n6envoy.config.filter.network.dubbo_proxy.v2alpha1.Route'
  _ROUTEMATCH._options = None
  _ROUTEMATCH._serialized_options = b'\232\305\210\036=\n;envoy.config.filter.network.dubbo_proxy.v2alpha1.RouteMatch'
  _ROUTEACTION.oneofs_by_name['cluster_specifier']._options = None
  _ROUTEACTION.oneofs_by_name['cluster_specifier']._serialized_options = b'\370B\001'
  _ROUTEACTION._options = None
  _ROUTEACTION._serialized_options = b'\232\305\210\036>\n<envoy.config.filter.network.dubbo_proxy.v2alpha1.RouteAction'
  _METHODMATCH_PARAMETERMATCHSPECIFIER._options = None
  _METHODMATCH_PARAMETERMATCHSPECIFIER._serialized_options = b'\232\305\210\036V\nTenvoy.config.filter.network.dubbo_proxy.v2alpha1.MethodMatch.ParameterMatchSpecifier'
  _METHODMATCH_PARAMSMATCHENTRY._options = None
  _METHODMATCH_PARAMSMATCHENTRY._serialized_options = b'8\001'
  _METHODMATCH._options = None
  _METHODMATCH._serialized_options = b'\232\305\210\036>\n<envoy.config.filter.network.dubbo_proxy.v2alpha1.MethodMatch'
  _globals['_ROUTECONFIGURATION']._serialized_start=346
  _globals['_ROUTECONFIGURATION']._serialized_end=579
  _globals['_ROUTE']._serialized_start=582
  _globals['_ROUTE']._serialized_end=825
  _globals['_ROUTEMATCH']._serialized_start=828
  _globals['_ROUTEMATCH']._serialized_end=1041
  _globals['_ROUTEACTION']._serialized_start=1044
  _globals['_ROUTEACTION']._serialized_end=1296
  _globals['_METHODMATCH']._serialized_start=1299
  _globals['_METHODMATCH']._serialized_end=1896
  _globals['_METHODMATCH_PARAMETERMATCHSPECIFIER']._serialized_start=1468
  _globals['_METHODMATCH_PARAMETERMATCHSPECIFIER']._serialized_end=1688
  _globals['_METHODMATCH_PARAMSMATCHENTRY']._serialized_start=1691
  _globals['_METHODMATCH_PARAMSMATCHENTRY']._serialized_end=1827
  _globals['_MULTIPLEROUTECONFIGURATION']._serialized_start=1899
  _globals['_MULTIPLEROUTECONFIGURATION']._serialized_end=2032
# @@protoc_insertion_point(module_scope)
