# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/cluster/v2alpha/outlier_detection_event.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8envoy/data/cluster/v2alpha/outlier_detection_event.proto\x12\x1a\x65nvoy.data.cluster.v2alpha\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x96\x05\n\x15OutlierDetectionEvent\x12G\n\x04type\x18\x01 \x01(\x0e\x32/.envoy.data.cluster.v2alpha.OutlierEjectionTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\x16secs_since_last_action\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x1d\n\x0c\x63luster_name\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x1d\n\x0cupstream_url\x18\x05 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12<\n\x06\x61\x63tion\x18\x06 \x01(\x0e\x32\".envoy.data.cluster.v2alpha.ActionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x15\n\rnum_ejections\x18\x07 \x01(\r\x12\x10\n\x08\x65nforced\x18\x08 \x01(\x08\x12W\n\x18\x65ject_success_rate_event\x18\t \x01(\x0b\x32\x33.envoy.data.cluster.v2alpha.OutlierEjectSuccessRateH\x00\x12V\n\x17\x65ject_consecutive_event\x18\n \x01(\x0b\x32\x33.envoy.data.cluster.v2alpha.OutlierEjectConsecutiveH\x00\x12\x63\n\x1e\x65ject_failure_percentage_event\x18\x0b \x01(\x0b\x32\x39.envoy.data.cluster.v2alpha.OutlierEjectFailurePercentageH\x00\x42\x0c\n\x05\x65vent\x12\x03\xf8\x42\x01\"\xa6\x01\n\x17OutlierEjectSuccessRate\x12\"\n\x11host_success_rate\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x64\x12-\n\x1c\x63luster_average_success_rate\x18\x02 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x64\x12\x38\n\'cluster_success_rate_ejection_threshold\x18\x03 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x64\"\x19\n\x17OutlierEjectConsecutive\"C\n\x1dOutlierEjectFailurePercentage\x12\"\n\x11host_success_rate\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x64*\xdf\x01\n\x13OutlierEjectionType\x12\x13\n\x0f\x43ONSECUTIVE_5XX\x10\x00\x12\x1f\n\x1b\x43ONSECUTIVE_GATEWAY_FAILURE\x10\x01\x12\x10\n\x0cSUCCESS_RATE\x10\x02\x12$\n CONSECUTIVE_LOCAL_ORIGIN_FAILURE\x10\x03\x12\x1d\n\x19SUCCESS_RATE_LOCAL_ORIGIN\x10\x04\x12\x16\n\x12\x46\x41ILURE_PERCENTAGE\x10\x05\x12#\n\x1f\x46\x41ILURE_PERCENTAGE_LOCAL_ORIGIN\x10\x06* \n\x06\x41\x63tion\x12\t\n\x05\x45JECT\x10\x00\x12\x0b\n\x07UNEJECT\x10\x01\x42\xb0\x01\n(io.envoyproxy.envoy.data.cluster.v2alphaB\x1aOutlierDetectionEventProtoP\x01ZAgithub.com/envoyproxy/go-control-plane/envoy/data/cluster/v2alpha\xf2\x98\xfe\x8f\x05\x17\x12\x15\x65nvoy.data.cluster.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.data.cluster.v2alpha.outlier_detection_event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(io.envoyproxy.envoy.data.cluster.v2alphaB\032OutlierDetectionEventProtoP\001ZAgithub.com/envoyproxy/go-control-plane/envoy/data/cluster/v2alpha\362\230\376\217\005\027\022\025envoy.data.cluster.v3\272\200\310\321\006\002\020\001'
  _OUTLIERDETECTIONEVENT.oneofs_by_name['event']._options = None
  _OUTLIERDETECTIONEVENT.oneofs_by_name['event']._serialized_options = b'\370B\001'
  _OUTLIERDETECTIONEVENT.fields_by_name['type']._options = None
  _OUTLIERDETECTIONEVENT.fields_by_name['type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _OUTLIERDETECTIONEVENT.fields_by_name['cluster_name']._options = None
  _OUTLIERDETECTIONEVENT.fields_by_name['cluster_name']._serialized_options = b'\372B\004r\002 \001'
  _OUTLIERDETECTIONEVENT.fields_by_name['upstream_url']._options = None
  _OUTLIERDETECTIONEVENT.fields_by_name['upstream_url']._serialized_options = b'\372B\004r\002 \001'
  _OUTLIERDETECTIONEVENT.fields_by_name['action']._options = None
  _OUTLIERDETECTIONEVENT.fields_by_name['action']._serialized_options = b'\372B\005\202\001\002\020\001'
  _OUTLIEREJECTSUCCESSRATE.fields_by_name['host_success_rate']._options = None
  _OUTLIEREJECTSUCCESSRATE.fields_by_name['host_success_rate']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIEREJECTSUCCESSRATE.fields_by_name['cluster_average_success_rate']._options = None
  _OUTLIEREJECTSUCCESSRATE.fields_by_name['cluster_average_success_rate']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIEREJECTSUCCESSRATE.fields_by_name['cluster_success_rate_ejection_threshold']._options = None
  _OUTLIEREJECTSUCCESSRATE.fields_by_name['cluster_success_rate_ejection_threshold']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIEREJECTFAILUREPERCENTAGE.fields_by_name['host_success_rate']._options = None
  _OUTLIEREJECTFAILUREPERCENTAGE.fields_by_name['host_success_rate']._serialized_options = b'\372B\004*\002\030d'
  _globals['_OUTLIEREJECTIONTYPE']._serialized_start=1172
  _globals['_OUTLIEREJECTIONTYPE']._serialized_end=1395
  _globals['_ACTION']._serialized_start=1397
  _globals['_ACTION']._serialized_end=1429
  _globals['_OUTLIERDETECTIONEVENT']._serialized_start=242
  _globals['_OUTLIERDETECTIONEVENT']._serialized_end=904
  _globals['_OUTLIEREJECTSUCCESSRATE']._serialized_start=907
  _globals['_OUTLIEREJECTSUCCESSRATE']._serialized_end=1073
  _globals['_OUTLIEREJECTCONSECUTIVE']._serialized_start=1075
  _globals['_OUTLIEREJECTCONSECUTIVE']._serialized_end=1100
  _globals['_OUTLIEREJECTFAILUREPERCENTAGE']._serialized_start=1102
  _globals['_OUTLIEREJECTFAILUREPERCENTAGE']._serialized_end=1169
# @@protoc_insertion_point(module_scope)
