# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/core/config_source.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import grpc_service_pb2 as envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%envoy/api/v2/core/config_source.proto\x12\x11\x65nvoy.api.v2.core\x1a$envoy/api/v2/core/grpc_service.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa0\x04\n\x0f\x41piConfigSource\x12\x46\n\x08\x61pi_type\x18\x01 \x01(\x0e\x32*.envoy.api.v2.core.ApiConfigSource.ApiTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x46\n\x15transport_api_version\x18\x08 \x01(\x0e\x32\x1d.envoy.api.v2.core.ApiVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x15\n\rcluster_names\x18\x02 \x03(\t\x12\x35\n\rgrpc_services\x18\x04 \x03(\x0b\x32\x1e.envoy.api.v2.core.GrpcService\x12\x30\n\rrefresh_delay\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12<\n\x0frequest_timeout\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x41\n\x13rate_limit_settings\x18\x06 \x01(\x0b\x32$.envoy.api.v2.core.RateLimitSettings\x12&\n\x1eset_node_on_first_message_only\x18\x07 \x01(\x08\"T\n\x07\x41piType\x12%\n\x17UNSUPPORTED_REST_LEGACY\x10\x00\x1a\x08\x08\x01\xa8\xf7\xb4\x8b\x02\x01\x12\x08\n\x04REST\x10\x01\x12\x08\n\x04GRPC\x10\x02\x12\x0e\n\nDELTA_GRPC\x10\x03\"\x18\n\x16\x41ggregatedConfigSource\"Z\n\x10SelfConfigSource\x12\x46\n\x15transport_api_version\x18\x01 \x01(\x0e\x32\x1d.envoy.api.v2.core.ApiVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"\x86\x01\n\x11RateLimitSettings\x12\x30\n\nmax_tokens\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12?\n\tfill_rate\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0e\xfa\x42\x0b\x12\t!\x00\x00\x00\x00\x00\x00\x00\x00\"\xef\x02\n\x0c\x43onfigSource\x12\x0e\n\x04path\x18\x01 \x01(\tH\x00\x12?\n\x11\x61pi_config_source\x18\x02 \x01(\x0b\x32\".envoy.api.v2.core.ApiConfigSourceH\x00\x12\x38\n\x03\x61\x64s\x18\x03 \x01(\x0b\x32).envoy.api.v2.core.AggregatedConfigSourceH\x00\x12\x33\n\x04self\x18\x05 \x01(\x0b\x32#.envoy.api.v2.core.SelfConfigSourceH\x00\x12\x38\n\x15initial_fetch_timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x45\n\x14resource_api_version\x18\x06 \x01(\x0e\x32\x1d.envoy.api.v2.core.ApiVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x42\x1e\n\x17\x63onfig_source_specifier\x12\x03\xf8\x42\x01*.\n\nApiVersion\x12\x0c\n\x04\x41UTO\x10\x00\x1a\x02\x08\x01\x12\n\n\x02V2\x10\x01\x1a\x02\x08\x01\x12\x06\n\x02V3\x10\x02\x42\x94\x01\n\x1fio.envoyproxy.envoy.api.v2.coreB\x11\x43onfigSourceProtoP\x01Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\xf2\x98\xfe\x8f\x05\x16\x12\x14\x65nvoy.config.core.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.core.config_source_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037io.envoyproxy.envoy.api.v2.coreB\021ConfigSourceProtoP\001Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\362\230\376\217\005\026\022\024envoy.config.core.v3\272\200\310\321\006\002\020\001'
  _APIVERSION.values_by_name["AUTO"]._options = None
  _APIVERSION.values_by_name["AUTO"]._serialized_options = b'\010\001'
  _APIVERSION.values_by_name["V2"]._options = None
  _APIVERSION.values_by_name["V2"]._serialized_options = b'\010\001'
  _APICONFIGSOURCE_APITYPE.values_by_name["UNSUPPORTED_REST_LEGACY"]._options = None
  _APICONFIGSOURCE_APITYPE.values_by_name["UNSUPPORTED_REST_LEGACY"]._serialized_options = b'\010\001\250\367\264\213\002\001'
  _APICONFIGSOURCE.fields_by_name['api_type']._options = None
  _APICONFIGSOURCE.fields_by_name['api_type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _APICONFIGSOURCE.fields_by_name['transport_api_version']._options = None
  _APICONFIGSOURCE.fields_by_name['transport_api_version']._serialized_options = b'\372B\005\202\001\002\020\001'
  _APICONFIGSOURCE.fields_by_name['request_timeout']._options = None
  _APICONFIGSOURCE.fields_by_name['request_timeout']._serialized_options = b'\372B\005\252\001\002*\000'
  _SELFCONFIGSOURCE.fields_by_name['transport_api_version']._options = None
  _SELFCONFIGSOURCE.fields_by_name['transport_api_version']._serialized_options = b'\372B\005\202\001\002\020\001'
  _RATELIMITSETTINGS.fields_by_name['fill_rate']._options = None
  _RATELIMITSETTINGS.fields_by_name['fill_rate']._serialized_options = b'\372B\013\022\t!\000\000\000\000\000\000\000\000'
  _CONFIGSOURCE.oneofs_by_name['config_source_specifier']._options = None
  _CONFIGSOURCE.oneofs_by_name['config_source_specifier']._serialized_options = b'\370B\001'
  _CONFIGSOURCE.fields_by_name['resource_api_version']._options = None
  _CONFIGSOURCE.fields_by_name['resource_api_version']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_APIVERSION']._serialized_start=1459
  _globals['_APIVERSION']._serialized_end=1505
  _globals['_APICONFIGSOURCE']._serialized_start=288
  _globals['_APICONFIGSOURCE']._serialized_end=832
  _globals['_APICONFIGSOURCE_APITYPE']._serialized_start=748
  _globals['_APICONFIGSOURCE_APITYPE']._serialized_end=832
  _globals['_AGGREGATEDCONFIGSOURCE']._serialized_start=834
  _globals['_AGGREGATEDCONFIGSOURCE']._serialized_end=858
  _globals['_SELFCONFIGSOURCE']._serialized_start=860
  _globals['_SELFCONFIGSOURCE']._serialized_end=950
  _globals['_RATELIMITSETTINGS']._serialized_start=953
  _globals['_RATELIMITSETTINGS']._serialized_end=1087
  _globals['_CONFIGSOURCE']._serialized_start=1090
  _globals['_CONFIGSOURCE']._serialized_end=1457
# @@protoc_insertion_point(module_scope)
