# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.cluster.v3 import cluster_pb2 as envoy_dot_config_dot_cluster_dot_v3_dot_cluster__pb2
from envoy.config.common.key_value.v3 import config_pb2 as envoy_dot_config_dot_common_dot_key__value_dot_v3_dot_config__pb2
from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.config.core.v3 import resolver_pb2 as envoy_dot_config_dot_core_dot_v3_dot_resolver__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto\x12\x30\x65nvoy.extensions.common.dynamic_forward_proxy.v3\x1a%envoy/config/cluster/v3/cluster.proto\x1a-envoy/config/common/key_value/v3/config.proto\x1a\"envoy/config/core/v3/address.proto\x1a$envoy/config/core/v3/extension.proto\x1a#envoy/config/core/v3/resolver.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"U\n\x17\x44nsCacheCircuitBreakers\x12:\n\x14max_pending_requests\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\"\xa6\x08\n\x0e\x44nsCacheConfig\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12U\n\x11\x64ns_lookup_family\x18\x02 \x01(\x0e\x32\x30.envoy.config.cluster.v3.Cluster.DnsLookupFamilyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x41\n\x10\x64ns_refresh_rate\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xfa\x42\t\xaa\x01\x06\x32\x04\x10\xc0\x84=\x12\x43\n\x14\x64ns_min_refresh_rate\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x32\x02\x08\x05\x12\x35\n\x08host_ttl\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x38\n\tmax_hosts\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02 \x00\x12N\n\x18\x64ns_failure_refresh_rate\x18\x06 \x01(\x0b\x32,.envoy.config.cluster.v3.Cluster.RefreshRate\x12l\n\x19\x64ns_cache_circuit_breaker\x18\x07 \x01(\x0b\x32I.envoy.extensions.common.dynamic_forward_proxy.v3.DnsCacheCircuitBreakers\x12,\n\x17use_tcp_for_dns_lookups\x18\x08 \x01(\x08\x42\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12U\n\x15\x64ns_resolution_config\x18\t \x01(\x0b\x32).envoy.config.core.v3.DnsResolutionConfigB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12M\n\x19typed_dns_resolver_config\x18\x0c \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12\x41\n\x14preresolve_hostnames\x18\n \x03(\x0b\x32#.envoy.config.core.v3.SocketAddress\x12>\n\x11\x64ns_query_timeout\x18\x0b \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12O\n\x10key_value_config\x18\r \x01(\x0b\x32\x35.envoy.config.common.key_value.v3.KeyValueStoreConfig:G\x9a\xc5\x88\x1e\x42\n@envoy.config.common.dynamic_forward_proxy.v2alpha.DnsCacheConfigB\xca\x01\n>io.envoyproxy.envoy.extensions.common.dynamic_forward_proxy.v3B\rDnsCacheProtoP\x01Zogithub.com/envoyproxy/go-control-plane/envoy/extensions/common/dynamic_forward_proxy/v3;dynamic_forward_proxyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.common.dynamic_forward_proxy.v3.dns_cache_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>io.envoyproxy.envoy.extensions.common.dynamic_forward_proxy.v3B\rDnsCacheProtoP\001Zogithub.com/envoyproxy/go-control-plane/envoy/extensions/common/dynamic_forward_proxy/v3;dynamic_forward_proxyv3\272\200\310\321\006\002\020\002'
  _DNSCACHECONFIG.fields_by_name['name']._options = None
  _DNSCACHECONFIG.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _DNSCACHECONFIG.fields_by_name['dns_lookup_family']._options = None
  _DNSCACHECONFIG.fields_by_name['dns_lookup_family']._serialized_options = b'\372B\005\202\001\002\020\001'
  _DNSCACHECONFIG.fields_by_name['dns_refresh_rate']._options = None
  _DNSCACHECONFIG.fields_by_name['dns_refresh_rate']._serialized_options = b'\372B\t\252\001\0062\004\020\300\204='
  _DNSCACHECONFIG.fields_by_name['dns_min_refresh_rate']._options = None
  _DNSCACHECONFIG.fields_by_name['dns_min_refresh_rate']._serialized_options = b'\372B\007\252\001\0042\002\010\005'
  _DNSCACHECONFIG.fields_by_name['host_ttl']._options = None
  _DNSCACHECONFIG.fields_by_name['host_ttl']._serialized_options = b'\372B\005\252\001\002*\000'
  _DNSCACHECONFIG.fields_by_name['max_hosts']._options = None
  _DNSCACHECONFIG.fields_by_name['max_hosts']._serialized_options = b'\372B\004*\002 \000'
  _DNSCACHECONFIG.fields_by_name['use_tcp_for_dns_lookups']._options = None
  _DNSCACHECONFIG.fields_by_name['use_tcp_for_dns_lookups']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _DNSCACHECONFIG.fields_by_name['dns_resolution_config']._options = None
  _DNSCACHECONFIG.fields_by_name['dns_resolution_config']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _DNSCACHECONFIG.fields_by_name['dns_query_timeout']._options = None
  _DNSCACHECONFIG.fields_by_name['dns_query_timeout']._serialized_options = b'\372B\005\252\001\002*\000'
  _DNSCACHECONFIG._options = None
  _DNSCACHECONFIG._serialized_options = b'\232\305\210\036B\n@envoy.config.common.dynamic_forward_proxy.v2alpha.DnsCacheConfig'
  _globals['_DNSCACHECIRCUITBREAKERS']._serialized_start=507
  _globals['_DNSCACHECIRCUITBREAKERS']._serialized_end=592
  _globals['_DNSCACHECONFIG']._serialized_start=595
  _globals['_DNSCACHECONFIG']._serialized_end=1657
# @@protoc_insertion_point(module_scope)
