# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/rate_limit_descriptors/expr/v3/expr.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api.expr.v1alpha1 import syntax_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:envoy/extensions/rate_limit_descriptors/expr/v3/expr.proto\x12/envoy.extensions.rate_limit_descriptors.expr.v3\x1a%google/api/expr/v1alpha1/syntax.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa1\x01\n\nDescriptor\x12\x1f\n\x0e\x64\x65scriptor_key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\rskip_if_error\x18\x02 \x01(\x08\x12\x17\n\x04text\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x30\n\x06parsed\x18\x04 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprH\x00\x42\x10\n\x0e\x65xpr_specifierB\xb3\x01\n=io.envoyproxy.envoy.extensions.rate_limit_descriptors.expr.v3B\tExprProtoP\x01Z]github.com/envoyproxy/go-control-plane/envoy/extensions/rate_limit_descriptors/expr/v3;exprv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.rate_limit_descriptors.expr.v3.expr_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n=io.envoyproxy.envoy.extensions.rate_limit_descriptors.expr.v3B\tExprProtoP\001Z]github.com/envoyproxy/go-control-plane/envoy/extensions/rate_limit_descriptors/expr/v3;exprv3\272\200\310\321\006\002\020\002'
  _DESCRIPTOR.fields_by_name['descriptor_key']._options = None
  _DESCRIPTOR.fields_by_name['descriptor_key']._serialized_options = b'\372B\004r\002\020\001'
  _DESCRIPTOR.fields_by_name['text']._options = None
  _DESCRIPTOR.fields_by_name['text']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_DESCRIPTOR']._serialized_start=207
  _globals['_DESCRIPTOR']._serialized_end=368
# @@protoc_insertion_point(module_scope)
