# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/composite/v3/composite.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import config_source_pb2 as envoy_dot_config_dot_core_dot_v3_dot_config__source__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:envoy/extensions/filters/http/composite/v3/composite.proto\x12*envoy.extensions.filters.http.composite.v3\x1a(envoy/config/core/v3/config_source.proto\x1a$envoy/config/core/v3/extension.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x0b\n\tComposite\"m\n\rDynamicConfig\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x45\n\x10\x63onfig_discovery\x18\x02 \x01(\x0b\x32+.envoy.config.core.v3.ExtensionConfigSource\"\xd4\x01\n\x13\x45xecuteFilterAction\x12U\n\x0ctyped_config\x18\x01 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigB\x13\xf2\x98\xfe\x8f\x05\r\x12\x0b\x63onfig_type\x12\x66\n\x0e\x64ynamic_config\x18\x02 \x01(\x0b\x32\x39.envoy.extensions.filters.http.composite.v3.DynamicConfigB\x13\xf2\x98\xfe\x8f\x05\r\x12\x0b\x63onfig_typeB\xb3\x01\n8io.envoyproxy.envoy.extensions.filters.http.composite.v3B\x0e\x43ompositeProtoP\x01Z]github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/composite/v3;compositev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.composite.v3.composite_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n8io.envoyproxy.envoy.extensions.filters.http.composite.v3B\016CompositeProtoP\001Z]github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/composite/v3;compositev3\272\200\310\321\006\002\020\002'
  _DYNAMICCONFIG.fields_by_name['name']._options = None
  _DYNAMICCONFIG.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _EXECUTEFILTERACTION.fields_by_name['typed_config']._options = None
  _EXECUTEFILTERACTION.fields_by_name['typed_config']._serialized_options = b'\362\230\376\217\005\r\022\013config_type'
  _EXECUTEFILTERACTION.fields_by_name['dynamic_config']._options = None
  _EXECUTEFILTERACTION.fields_by_name['dynamic_config']._serialized_options = b'\362\230\376\217\005\r\022\013config_type'
  _globals['_COMPOSITE']._serialized_start=274
  _globals['_COMPOSITE']._serialized_end=285
  _globals['_DYNAMICCONFIG']._serialized_start=287
  _globals['_DYNAMICCONFIG']._serialized_end=396
  _globals['_EXECUTEFILTERACTION']._serialized_start=399
  _globals['_EXECUTEFILTERACTION']._serialized_end=611
# @@protoc_insertion_point(module_scope)
