# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/sni_dynamic_forward_proxy/v3/sni_dynamic_forward_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.common.dynamic_forward_proxy.v3 import dns_cache_pb2 as envoy_dot_extensions_dot_common_dot_dynamic__forward__proxy_dot_v3_dot_dns__cache__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n]envoy/extensions/filters/network/sni_dynamic_forward_proxy/v3/sni_dynamic_forward_proxy.proto\x12=envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3\x1a@envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa9\x01\n\x0c\x46ilterConfig\x12\x64\n\x10\x64ns_cache_config\x18\x01 \x01(\x0b\x32@.envoy.extensions.common.dynamic_forward_proxy.v3.DnsCacheConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12!\n\nport_value\x18\x02 \x01(\rB\x0b\xfa\x42\x08*\x06\x18\xff\xff\x03 \x00H\x00\x42\x10\n\x0eport_specifierB\xf7\x01\nKio.envoyproxy.envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3B\x1bSniDynamicForwardProxyProtoP\x01Z\x80\x01github.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/sni_dynamic_forward_proxy/v3;sni_dynamic_forward_proxyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3.sni_dynamic_forward_proxy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nKio.envoyproxy.envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3B\033SniDynamicForwardProxyProtoP\001Z\200\001github.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/sni_dynamic_forward_proxy/v3;sni_dynamic_forward_proxyv3\272\200\310\321\006\002\020\002'
  _FILTERCONFIG.fields_by_name['dns_cache_config']._options = None
  _FILTERCONFIG.fields_by_name['dns_cache_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _FILTERCONFIG.fields_by_name['port_value']._options = None
  _FILTERCONFIG.fields_by_name['port_value']._serialized_options = b'\372B\010*\006\030\377\377\003 \000'
  _globals['_FILTERCONFIG']._serialized_start=283
  _globals['_FILTERCONFIG']._serialized_end=452
# @@protoc_insertion_point(module_scope)
