# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/accesslog/v3/accesslog.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from envoy.data.accesslog.v3 import accesslog_pb2 as envoy_dot_data_dot_accesslog_dot_v3_dot_accesslog__pb2
from envoy.type.matcher.v3 import metadata_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_metadata__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)envoy/config/accesslog/v3/accesslog.proto\x12\x19\x65nvoy.config.accesslog.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a,envoy/config/route/v3/route_components.proto\x1a\'envoy/data/accesslog/v3/accesslog.proto\x1a$envoy/type/matcher/v3/metadata.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xd3\x01\n\tAccessLog\x12\x0c\n\x04name\x18\x01 \x01(\t\x12:\n\x06\x66ilter\x18\x02 \x01(\x0b\x32*.envoy.config.accesslog.v3.AccessLogFilter\x12,\n\x0ctyped_config\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:1\x9a\xc5\x88\x1e,\n*envoy.config.filter.accesslog.v2.AccessLogB\r\n\x0b\x63onfig_typeJ\x04\x08\x03\x10\x04R\x06\x63onfig\"\xf9\x07\n\x0f\x41\x63\x63\x65ssLogFilter\x12I\n\x12status_code_filter\x18\x01 \x01(\x0b\x32+.envoy.config.accesslog.v3.StatusCodeFilterH\x00\x12\x44\n\x0f\x64uration_filter\x18\x02 \x01(\x0b\x32).envoy.config.accesslog.v3.DurationFilterH\x00\x12R\n\x17not_health_check_filter\x18\x03 \x01(\x0b\x32/.envoy.config.accesslog.v3.NotHealthCheckFilterH\x00\x12\x46\n\x10traceable_filter\x18\x04 \x01(\x0b\x32*.envoy.config.accesslog.v3.TraceableFilterH\x00\x12\x42\n\x0eruntime_filter\x18\x05 \x01(\x0b\x32(.envoy.config.accesslog.v3.RuntimeFilterH\x00\x12:\n\nand_filter\x18\x06 \x01(\x0b\x32$.envoy.config.accesslog.v3.AndFilterH\x00\x12\x38\n\tor_filter\x18\x07 \x01(\x0b\x32#.envoy.config.accesslog.v3.OrFilterH\x00\x12@\n\rheader_filter\x18\x08 \x01(\x0b\x32\'.envoy.config.accesslog.v3.HeaderFilterH\x00\x12M\n\x14response_flag_filter\x18\t \x01(\x0b\x32-.envoy.config.accesslog.v3.ResponseFlagFilterH\x00\x12I\n\x12grpc_status_filter\x18\n \x01(\x0b\x32+.envoy.config.accesslog.v3.GrpcStatusFilterH\x00\x12\x46\n\x10\x65xtension_filter\x18\x0b \x01(\x0b\x32*.envoy.config.accesslog.v3.ExtensionFilterH\x00\x12\x44\n\x0fmetadata_filter\x18\x0c \x01(\x0b\x32).envoy.config.accesslog.v3.MetadataFilterH\x00\x12\x43\n\x0flog_type_filter\x18\r \x01(\x0b\x32(.envoy.config.accesslog.v3.LogTypeFilterH\x00:7\x9a\xc5\x88\x1e\x32\n0envoy.config.filter.accesslog.v2.AccessLogFilterB\x17\n\x10\x66ilter_specifier\x12\x03\xf8\x42\x01\"\xee\x01\n\x10\x43omparisonFilter\x12\x44\n\x02op\x18\x01 \x01(\x0e\x32..envoy.config.accesslog.v3.ComparisonFilter.OpB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12<\n\x05value\x18\x02 \x01(\x0b\x32#.envoy.config.core.v3.RuntimeUInt32B\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x1c\n\x02Op\x12\x06\n\x02\x45Q\x10\x00\x12\x06\n\x02GE\x10\x01\x12\x06\n\x02LE\x10\x02:8\x9a\xc5\x88\x1e\x33\n1envoy.config.filter.accesslog.v2.ComparisonFilter\"\x97\x01\n\x10StatusCodeFilter\x12I\n\ncomparison\x18\x01 \x01(\x0b\x32+.envoy.config.accesslog.v3.ComparisonFilterB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:8\x9a\xc5\x88\x1e\x33\n1envoy.config.filter.accesslog.v2.StatusCodeFilter\"\x93\x01\n\x0e\x44urationFilter\x12I\n\ncomparison\x18\x01 \x01(\x0b\x32+.envoy.config.accesslog.v3.ComparisonFilterB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:6\x9a\xc5\x88\x1e\x31\n/envoy.config.filter.accesslog.v2.DurationFilter\"T\n\x14NotHealthCheckFilter:<\x9a\xc5\x88\x1e\x37\n5envoy.config.filter.accesslog.v2.NotHealthCheckFilter\"J\n\x0fTraceableFilter:7\x9a\xc5\x88\x1e\x32\n0envoy.config.filter.accesslog.v2.TraceableFilter\"\xc3\x01\n\rRuntimeFilter\x12\x1c\n\x0bruntime_key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x39\n\x0fpercent_sampled\x18\x02 \x01(\x0b\x32 .envoy.type.v3.FractionalPercent\x12\"\n\x1ause_independent_randomness\x18\x03 \x01(\x08:5\x9a\xc5\x88\x1e\x30\n.envoy.config.filter.accesslog.v2.RuntimeFilter\"\x85\x01\n\tAndFilter\x12\x45\n\x07\x66ilters\x18\x01 \x03(\x0b\x32*.envoy.config.accesslog.v3.AccessLogFilterB\x08\xfa\x42\x05\x92\x01\x02\x08\x02:1\x9a\xc5\x88\x1e,\n*envoy.config.filter.accesslog.v2.AndFilter\"\x83\x01\n\x08OrFilter\x12\x45\n\x07\x66ilters\x18\x02 \x03(\x0b\x32*.envoy.config.accesslog.v3.AccessLogFilterB\x08\xfa\x42\x05\x92\x01\x02\x08\x02:0\x9a\xc5\x88\x1e+\n)envoy.config.filter.accesslog.v2.OrFilter\"\x84\x01\n\x0cHeaderFilter\x12>\n\x06header\x18\x01 \x01(\x0b\x32$.envoy.config.route.v3.HeaderMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:4\x9a\xc5\x88\x1e/\n-envoy.config.filter.accesslog.v2.HeaderFilter\"\xee\x01\n\x12ResponseFlagFilter\x12\x9b\x01\n\x05\x66lags\x18\x01 \x03(\tB\x8b\x01\xfa\x42\x87\x01\x92\x01\x83\x01\"\x80\x01r~R\x02LHR\x02UHR\x02UTR\x02LRR\x02URR\x02UFR\x02UCR\x02UOR\x02NRR\x02\x44IR\x02\x46IR\x02RLR\x04UAEXR\x04RLSER\x02\x44\x43R\x03URXR\x02SIR\x02IHR\x03\x44PER\x05UMSDRR\x04RFCFR\x04NFCFR\x02\x44TR\x03UPER\x02NCR\x02OMR\x02\x44\x46R\x02\x44O::\x9a\xc5\x88\x1e\x35\n3envoy.config.filter.accesslog.v2.ResponseFlagFilter\"\xed\x03\n\x10GrpcStatusFilter\x12S\n\x08statuses\x18\x01 \x03(\x0e\x32\x32.envoy.config.accesslog.v3.GrpcStatusFilter.StatusB\r\xfa\x42\n\x92\x01\x07\"\x05\x82\x01\x02\x10\x01\x12\x0f\n\x07\x65xclude\x18\x02 \x01(\x08\"\xb8\x02\n\x06Status\x12\x06\n\x02OK\x10\x00\x12\x0c\n\x08\x43\x41NCELED\x10\x01\x12\x0b\n\x07UNKNOWN\x10\x02\x12\x14\n\x10INVALID_ARGUMENT\x10\x03\x12\x15\n\x11\x44\x45\x41\x44LINE_EXCEEDED\x10\x04\x12\r\n\tNOT_FOUND\x10\x05\x12\x12\n\x0e\x41LREADY_EXISTS\x10\x06\x12\x15\n\x11PERMISSION_DENIED\x10\x07\x12\x16\n\x12RESOURCE_EXHAUSTED\x10\x08\x12\x17\n\x13\x46\x41ILED_PRECONDITION\x10\t\x12\x0b\n\x07\x41\x42ORTED\x10\n\x12\x10\n\x0cOUT_OF_RANGE\x10\x0b\x12\x11\n\rUNIMPLEMENTED\x10\x0c\x12\x0c\n\x08INTERNAL\x10\r\x12\x0f\n\x0bUNAVAILABLE\x10\x0e\x12\r\n\tDATA_LOSS\x10\x0f\x12\x13\n\x0fUNAUTHENTICATED\x10\x10:8\x9a\xc5\x88\x1e\x33\n1envoy.config.filter.accesslog.v2.GrpcStatusFilter\"\xbd\x01\n\x0eMetadataFilter\x12\x37\n\x07matcher\x18\x01 \x01(\x0b\x32&.envoy.type.matcher.v3.MetadataMatcher\x12:\n\x16match_if_key_not_found\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue:6\x9a\xc5\x88\x1e\x31\n/envoy.config.filter.accesslog.v2.MetadataFilter\"f\n\rLogTypeFilter\x12\x44\n\x05types\x18\x01 \x03(\x0e\x32&.envoy.data.accesslog.v3.AccessLogTypeB\r\xfa\x42\n\x92\x01\x07\"\x05\x82\x01\x02\x10\x01\x12\x0f\n\x07\x65xclude\x18\x02 \x01(\x08\"\xa3\x01\n\x0f\x45xtensionFilter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:7\x9a\xc5\x88\x1e\x32\n0envoy.config.filter.accesslog.v2.ExtensionFilterB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfigB\x91\x01\n\'io.envoyproxy.envoy.config.accesslog.v3B\x0e\x41\x63\x63\x65sslogProtoP\x01ZLgithub.com/envoyproxy/go-control-plane/envoy/config/accesslog/v3;accesslogv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.accesslog.v3.accesslog_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'io.envoyproxy.envoy.config.accesslog.v3B\016AccesslogProtoP\001ZLgithub.com/envoyproxy/go-control-plane/envoy/config/accesslog/v3;accesslogv3\272\200\310\321\006\002\020\002'
  _ACCESSLOG._options = None
  _ACCESSLOG._serialized_options = b'\232\305\210\036,\n*envoy.config.filter.accesslog.v2.AccessLog'
  _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']._options = None
  _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']._serialized_options = b'\370B\001'
  _ACCESSLOGFILTER._options = None
  _ACCESSLOGFILTER._serialized_options = b'\232\305\210\0362\n0envoy.config.filter.accesslog.v2.AccessLogFilter'
  _COMPARISONFILTER.fields_by_name['op']._options = None
  _COMPARISONFILTER.fields_by_name['op']._serialized_options = b'\372B\005\202\001\002\020\001'
  _COMPARISONFILTER.fields_by_name['value']._options = None
  _COMPARISONFILTER.fields_by_name['value']._serialized_options = b'\372B\005\212\001\002\020\001'
  _COMPARISONFILTER._options = None
  _COMPARISONFILTER._serialized_options = b'\232\305\210\0363\n1envoy.config.filter.accesslog.v2.ComparisonFilter'
  _STATUSCODEFILTER.fields_by_name['comparison']._options = None
  _STATUSCODEFILTER.fields_by_name['comparison']._serialized_options = b'\372B\005\212\001\002\020\001'
  _STATUSCODEFILTER._options = None
  _STATUSCODEFILTER._serialized_options = b'\232\305\210\0363\n1envoy.config.filter.accesslog.v2.StatusCodeFilter'
  _DURATIONFILTER.fields_by_name['comparison']._options = None
  _DURATIONFILTER.fields_by_name['comparison']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DURATIONFILTER._options = None
  _DURATIONFILTER._serialized_options = b'\232\305\210\0361\n/envoy.config.filter.accesslog.v2.DurationFilter'
  _NOTHEALTHCHECKFILTER._options = None
  _NOTHEALTHCHECKFILTER._serialized_options = b'\232\305\210\0367\n5envoy.config.filter.accesslog.v2.NotHealthCheckFilter'
  _TRACEABLEFILTER._options = None
  _TRACEABLEFILTER._serialized_options = b'\232\305\210\0362\n0envoy.config.filter.accesslog.v2.TraceableFilter'
  _RUNTIMEFILTER.fields_by_name['runtime_key']._options = None
  _RUNTIMEFILTER.fields_by_name['runtime_key']._serialized_options = b'\372B\004r\002\020\001'
  _RUNTIMEFILTER._options = None
  _RUNTIMEFILTER._serialized_options = b'\232\305\210\0360\n.envoy.config.filter.accesslog.v2.RuntimeFilter'
  _ANDFILTER.fields_by_name['filters']._options = None
  _ANDFILTER.fields_by_name['filters']._serialized_options = b'\372B\005\222\001\002\010\002'
  _ANDFILTER._options = None
  _ANDFILTER._serialized_options = b'\232\305\210\036,\n*envoy.config.filter.accesslog.v2.AndFilter'
  _ORFILTER.fields_by_name['filters']._options = None
  _ORFILTER.fields_by_name['filters']._serialized_options = b'\372B\005\222\001\002\010\002'
  _ORFILTER._options = None
  _ORFILTER._serialized_options = b'\232\305\210\036+\n)envoy.config.filter.accesslog.v2.OrFilter'
  _HEADERFILTER.fields_by_name['header']._options = None
  _HEADERFILTER.fields_by_name['header']._serialized_options = b'\372B\005\212\001\002\020\001'
  _HEADERFILTER._options = None
  _HEADERFILTER._serialized_options = b'\232\305\210\036/\n-envoy.config.filter.accesslog.v2.HeaderFilter'
  _RESPONSEFLAGFILTER.fields_by_name['flags']._options = None
  _RESPONSEFLAGFILTER.fields_by_name['flags']._serialized_options = b'\372B\207\001\222\001\203\001\"\200\001r~R\002LHR\002UHR\002UTR\002LRR\002URR\002UFR\002UCR\002UOR\002NRR\002DIR\002FIR\002RLR\004UAEXR\004RLSER\002DCR\003URXR\002SIR\002IHR\003DPER\005UMSDRR\004RFCFR\004NFCFR\002DTR\003UPER\002NCR\002OMR\002DFR\002DO'
  _RESPONSEFLAGFILTER._options = None
  _RESPONSEFLAGFILTER._serialized_options = b'\232\305\210\0365\n3envoy.config.filter.accesslog.v2.ResponseFlagFilter'
  _GRPCSTATUSFILTER.fields_by_name['statuses']._options = None
  _GRPCSTATUSFILTER.fields_by_name['statuses']._serialized_options = b'\372B\n\222\001\007\"\005\202\001\002\020\001'
  _GRPCSTATUSFILTER._options = None
  _GRPCSTATUSFILTER._serialized_options = b'\232\305\210\0363\n1envoy.config.filter.accesslog.v2.GrpcStatusFilter'
  _METADATAFILTER._options = None
  _METADATAFILTER._serialized_options = b'\232\305\210\0361\n/envoy.config.filter.accesslog.v2.MetadataFilter'
  _LOGTYPEFILTER.fields_by_name['types']._options = None
  _LOGTYPEFILTER.fields_by_name['types']._serialized_options = b'\372B\n\222\001\007\"\005\202\001\002\020\001'
  _EXTENSIONFILTER._options = None
  _EXTENSIONFILTER._serialized_options = b'\232\305\210\0362\n0envoy.config.filter.accesslog.v2.ExtensionFilter'
  _globals['_ACCESSLOG']._serialized_start=410
  _globals['_ACCESSLOG']._serialized_end=621
  _globals['_ACCESSLOGFILTER']._serialized_start=624
  _globals['_ACCESSLOGFILTER']._serialized_end=1641
  _globals['_COMPARISONFILTER']._serialized_start=1644
  _globals['_COMPARISONFILTER']._serialized_end=1882
  _globals['_COMPARISONFILTER_OP']._serialized_start=1796
  _globals['_COMPARISONFILTER_OP']._serialized_end=1824
  _globals['_STATUSCODEFILTER']._serialized_start=1885
  _globals['_STATUSCODEFILTER']._serialized_end=2036
  _globals['_DURATIONFILTER']._serialized_start=2039
  _globals['_DURATIONFILTER']._serialized_end=2186
  _globals['_NOTHEALTHCHECKFILTER']._serialized_start=2188
  _globals['_NOTHEALTHCHECKFILTER']._serialized_end=2272
  _globals['_TRACEABLEFILTER']._serialized_start=2274
  _globals['_TRACEABLEFILTER']._serialized_end=2348
  _globals['_RUNTIMEFILTER']._serialized_start=2351
  _globals['_RUNTIMEFILTER']._serialized_end=2546
  _globals['_ANDFILTER']._serialized_start=2549
  _globals['_ANDFILTER']._serialized_end=2682
  _globals['_ORFILTER']._serialized_start=2685
  _globals['_ORFILTER']._serialized_end=2816
  _globals['_HEADERFILTER']._serialized_start=2819
  _globals['_HEADERFILTER']._serialized_end=2951
  _globals['_RESPONSEFLAGFILTER']._serialized_start=2954
  _globals['_RESPONSEFLAGFILTER']._serialized_end=3192
  _globals['_GRPCSTATUSFILTER']._serialized_start=3195
  _globals['_GRPCSTATUSFILTER']._serialized_end=3688
  _globals['_GRPCSTATUSFILTER_STATUS']._serialized_start=3318
  _globals['_GRPCSTATUSFILTER_STATUS']._serialized_end=3630
  _globals['_METADATAFILTER']._serialized_start=3691
  _globals['_METADATAFILTER']._serialized_end=3880
  _globals['_LOGTYPEFILTER']._serialized_start=3882
  _globals['_LOGTYPEFILTER']._serialized_end=3984
  _globals['_EXTENSIONFILTER']._serialized_start=3987
  _globals['_EXTENSIONFILTER']._serialized_end=4150
# @@protoc_insertion_point(module_scope)
