# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/compression/gzip/compressor/v3/gzip.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:envoy/extensions/compression/gzip/compressor/v3/gzip.proto\x12/envoy.extensions.compression.gzip.compressor.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xbd\x06\n\x04Gzip\x12=\n\x0cmemory_level\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18\t(\x01\x12k\n\x11\x63ompression_level\x18\x02 \x01(\x0e\x32\x46.envoy.extensions.compression.gzip.compressor.v3.Gzip.CompressionLevelB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12q\n\x14\x63ompression_strategy\x18\x03 \x01(\x0e\x32I.envoy.extensions.compression.gzip.compressor.v3.Gzip.CompressionStrategyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12<\n\x0bwindow_bits\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18\x0f(\t\x12>\n\nchunk_size\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0c\xfa\x42\t*\x07\x18\x80\x80\x04(\x80 \"_\n\x13\x43ompressionStrategy\x12\x14\n\x10\x44\x45\x46\x41ULT_STRATEGY\x10\x00\x12\x0c\n\x08\x46ILTERED\x10\x01\x12\x10\n\x0cHUFFMAN_ONLY\x10\x02\x12\x07\n\x03RLE\x10\x03\x12\t\n\x05\x46IXED\x10\x04\"\xb6\x02\n\x10\x43ompressionLevel\x12\x17\n\x13\x44\x45\x46\x41ULT_COMPRESSION\x10\x00\x12\x0e\n\nBEST_SPEED\x10\x01\x12\x17\n\x13\x43OMPRESSION_LEVEL_1\x10\x01\x12\x17\n\x13\x43OMPRESSION_LEVEL_2\x10\x02\x12\x17\n\x13\x43OMPRESSION_LEVEL_3\x10\x03\x12\x17\n\x13\x43OMPRESSION_LEVEL_4\x10\x04\x12\x17\n\x13\x43OMPRESSION_LEVEL_5\x10\x05\x12\x17\n\x13\x43OMPRESSION_LEVEL_6\x10\x06\x12\x17\n\x13\x43OMPRESSION_LEVEL_7\x10\x07\x12\x17\n\x13\x43OMPRESSION_LEVEL_8\x10\x08\x12\x17\n\x13\x43OMPRESSION_LEVEL_9\x10\t\x12\x14\n\x10\x42\x45ST_COMPRESSION\x10\t\x1a\x02\x10\x01\x42\xb9\x01\n=io.envoyproxy.envoy.extensions.compression.gzip.compressor.v3B\tGzipProtoP\x01Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/compression/gzip/compressor/v3;compressorv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.compression.gzip.compressor.v3.gzip_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n=io.envoyproxy.envoy.extensions.compression.gzip.compressor.v3B\tGzipProtoP\001Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/compression/gzip/compressor/v3;compressorv3\272\200\310\321\006\002\020\002'
  _GZIP_COMPRESSIONLEVEL._options = None
  _GZIP_COMPRESSIONLEVEL._serialized_options = b'\020\001'
  _GZIP.fields_by_name['memory_level']._options = None
  _GZIP.fields_by_name['memory_level']._serialized_options = b'\372B\006*\004\030\t(\001'
  _GZIP.fields_by_name['compression_level']._options = None
  _GZIP.fields_by_name['compression_level']._serialized_options = b'\372B\005\202\001\002\020\001'
  _GZIP.fields_by_name['compression_strategy']._options = None
  _GZIP.fields_by_name['compression_strategy']._serialized_options = b'\372B\005\202\001\002\020\001'
  _GZIP.fields_by_name['window_bits']._options = None
  _GZIP.fields_by_name['window_bits']._serialized_options = b'\372B\006*\004\030\017(\t'
  _GZIP.fields_by_name['chunk_size']._options = None
  _GZIP.fields_by_name['chunk_size']._serialized_options = b'\372B\t*\007\030\200\200\004(\200 '
  _globals['_GZIP']._serialized_start=200
  _globals['_GZIP']._serialized_end=1029
  _globals['_GZIP_COMPRESSIONSTRATEGY']._serialized_start=621
  _globals['_GZIP_COMPRESSIONSTRATEGY']._serialized_end=716
  _globals['_GZIP_COMPRESSIONLEVEL']._serialized_start=719
  _globals['_GZIP_COMPRESSIONLEVEL']._serialized_end=1029
# @@protoc_insertion_point(module_scope)
