# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/compression/zstd/compressor/v3/zstd.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:envoy/extensions/compression/zstd/compressor/v3/zstd.proto\x12/envoy.extensions.compression.zstd.compressor.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xad\x03\n\x04Zstd\x12\x37\n\x11\x63ompression_level\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x17\n\x0f\x65nable_checksum\x18\x02 \x01(\x08\x12Z\n\x08strategy\x18\x03 \x01(\x0e\x32>.envoy.extensions.compression.zstd.compressor.v3.Zstd.StrategyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x34\n\ndictionary\x18\x04 \x01(\x0b\x32 .envoy.config.core.v3.DataSource\x12>\n\nchunk_size\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0c\xfa\x42\t*\x07\x18\x80\x80\x04(\x80 \"\x80\x01\n\x08Strategy\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x08\n\x04\x46\x41ST\x10\x01\x12\t\n\x05\x44\x46\x41ST\x10\x02\x12\n\n\x06GREEDY\x10\x03\x12\x08\n\x04LAZY\x10\x04\x12\t\n\x05LAZY2\x10\x05\x12\x0b\n\x07\x42TLAZY2\x10\x06\x12\t\n\x05\x42TOPT\x10\x07\x12\x0b\n\x07\x42TULTRA\x10\x08\x12\x0c\n\x08\x42TULTRA2\x10\tB\xb9\x01\n=io.envoyproxy.envoy.extensions.compression.zstd.compressor.v3B\tZstdProtoP\x01Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/compression/zstd/compressor/v3;compressorv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.compression.zstd.compressor.v3.zstd_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n=io.envoyproxy.envoy.extensions.compression.zstd.compressor.v3B\tZstdProtoP\001Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/compression/zstd/compressor/v3;compressorv3\272\200\310\321\006\002\020\002'
  _ZSTD.fields_by_name['strategy']._options = None
  _ZSTD.fields_by_name['strategy']._serialized_options = b'\372B\005\202\001\002\020\001'
  _ZSTD.fields_by_name['chunk_size']._options = None
  _ZSTD.fields_by_name['chunk_size']._serialized_options = b'\372B\t*\007\030\200\200\004(\200 '
  _globals['_ZSTD']._serialized_start=233
  _globals['_ZSTD']._serialized_end=662
  _globals['_ZSTD_STRATEGY']._serialized_start=534
  _globals['_ZSTD_STRATEGY']._serialized_end=662
# @@protoc_insertion_point(module_scope)
