# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/core/base.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import backoff_pb2 as envoy_dot_api_dot_v2_dot_core_dot_backoff__pb2
from envoy.api.v2.core import http_uri_pb2 as envoy_dot_api_dot_v2_dot_core_dot_http__uri__pb2
from envoy.type import percent_pb2 as envoy_dot_type_dot_percent__pb2
from envoy.type import semantic_version_pb2 as envoy_dot_type_dot_semantic__version__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2
from envoy.api.v2.core import socket_option_pb2 as envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2

from envoy.api.v2.core.socket_option_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65nvoy/api/v2/core/base.proto\x12\x11\x65nvoy.api.v2.core\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1f\x65nvoy/api/v2/core/backoff.proto\x1a envoy/api/v2/core/http_uri.proto\x1a\x18\x65nvoy/type/percent.proto\x1a!envoy/type/semantic_version.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\x1a%envoy/api/v2/core/socket_option.proto\":\n\x08Locality\x12\x0e\n\x06region\x18\x01 \x01(\t\x12\x0c\n\x04zone\x18\x02 \x01(\t\x12\x10\n\x08sub_zone\x18\x03 \x01(\t\"g\n\x0c\x42uildVersion\x12,\n\x07version\x18\x01 \x01(\x0b\x32\x1b.envoy.type.SemanticVersion\x12)\n\x08metadata\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x88\x01\n\tExtension\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x17\n\x0ftype_descriptor\x18\x03 \x01(\t\x12\x30\n\x07version\x18\x04 \x01(\x0b\x32\x1f.envoy.api.v2.core.BuildVersion\x12\x10\n\x08\x64isabled\x18\x05 \x01(\x08\"\xb3\x03\n\x04Node\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x63luster\x18\x02 \x01(\t\x12)\n\x08metadata\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12-\n\x08locality\x18\x04 \x01(\x0b\x32\x1b.envoy.api.v2.core.Locality\x12\x19\n\rbuild_version\x18\x05 \x01(\tB\x02\x18\x01\x12\x17\n\x0fuser_agent_name\x18\x06 \x01(\t\x12\x1c\n\x12user_agent_version\x18\x07 \x01(\tH\x00\x12\x43\n\x18user_agent_build_version\x18\x08 \x01(\x0b\x32\x1f.envoy.api.v2.core.BuildVersionH\x00\x12\x30\n\nextensions\x18\t \x03(\x0b\x32\x1c.envoy.api.v2.core.Extension\x12\x17\n\x0f\x63lient_features\x18\n \x03(\t\x12\x37\n\x13listening_addresses\x18\x0b \x03(\x0b\x32\x1a.envoy.api.v2.core.AddressB\x19\n\x17user_agent_version_type\"\xa4\x01\n\x08Metadata\x12H\n\x0f\x66ilter_metadata\x18\x01 \x03(\x0b\x32/.envoy.api.v2.core.Metadata.FilterMetadataEntry\x1aN\n\x13\x46ilterMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:\x02\x38\x01\"D\n\rRuntimeUInt32\x12\x15\n\rdefault_value\x18\x02 \x01(\r\x12\x1c\n\x0bruntime_key\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\"D\n\rRuntimeDouble\x12\x15\n\rdefault_value\x18\x01 \x01(\x01\x12\x1c\n\x0bruntime_key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\"o\n\x12RuntimeFeatureFlag\x12;\n\rdefault_value\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1c\n\x0bruntime_key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\"M\n\x0bHeaderValue\x12\x1e\n\x03key\x18\x01 \x01(\tB\x11\xfa\x42\x0er\x0c \x01(\x80\x80\x01\xc0\x01\x01\xc8\x01\x00\x12\x1e\n\x05value\x18\x02 \x01(\tB\x0f\xfa\x42\x0cr\n(\x80\x80\x01\xc0\x01\x02\xc8\x01\x00\"y\n\x11HeaderValueOption\x12\x38\n\x06header\x18\x01 \x01(\x0b\x32\x1e.envoy.api.v2.core.HeaderValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12*\n\x06\x61ppend\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"<\n\tHeaderMap\x12/\n\x07headers\x18\x01 \x03(\x0b\x32\x1e.envoy.api.v2.core.HeaderValue\"~\n\nDataSource\x12\x1b\n\x08\x66ilename\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01H\x00\x12\x1f\n\x0cinline_bytes\x18\x02 \x01(\x0c\x42\x07\xfa\x42\x04z\x02\x10\x01H\x00\x12 \n\rinline_string\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02 \x01H\x00\x42\x10\n\tspecifier\x12\x03\xf8\x42\x01\"|\n\x0bRetryPolicy\x12:\n\x0eretry_back_off\x18\x01 \x01(\x0b\x32\".envoy.api.v2.core.BackoffStrategy\x12\x31\n\x0bnum_retries\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\"\x99\x01\n\x10RemoteDataSource\x12\x36\n\x08http_uri\x18\x01 \x01(\x0b\x32\x1a.envoy.api.v2.core.HttpUriB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x17\n\x06sha256\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x34\n\x0cretry_policy\x18\x03 \x01(\x0b\x32\x1e.envoy.api.v2.core.RetryPolicy\"\x8a\x01\n\x0f\x41syncDataSource\x12.\n\x05local\x18\x01 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceH\x00\x12\x35\n\x06remote\x18\x02 \x01(\x0b\x32#.envoy.api.v2.core.RemoteDataSourceH\x00\x42\x10\n\tspecifier\x12\x03\xf8\x42\x01\"\x94\x01\n\x0fTransportSocket\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\r\n\x0b\x63onfig_type\"o\n\x18RuntimeFractionalPercent\x12>\n\rdefault_value\x18\x01 \x01(\x0b\x32\x1d.envoy.type.FractionalPercentB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x13\n\x0bruntime_key\x18\x02 \x01(\t\"\"\n\x0c\x43ontrolPlane\x12\x12\n\nidentifier\x18\x01 \x01(\t*(\n\x0fRoutingPriority\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x08\n\x04HIGH\x10\x01*\x89\x01\n\rRequestMethod\x12\x16\n\x12METHOD_UNSPECIFIED\x10\x00\x12\x07\n\x03GET\x10\x01\x12\x08\n\x04HEAD\x10\x02\x12\x08\n\x04POST\x10\x03\x12\x07\n\x03PUT\x10\x04\x12\n\n\x06\x44\x45LETE\x10\x05\x12\x0b\n\x07\x43ONNECT\x10\x06\x12\x0b\n\x07OPTIONS\x10\x07\x12\t\n\x05TRACE\x10\x08\x12\t\n\x05PATCH\x10\t*>\n\x10TrafficDirection\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07INBOUND\x10\x01\x12\x0c\n\x08OUTBOUND\x10\x02\x42\x8c\x01\n\x1fio.envoyproxy.envoy.api.v2.coreB\tBaseProtoP\x01Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\xf2\x98\xfe\x8f\x05\x16\x12\x14\x65nvoy.config.core.v3\xba\x80\xc8\xd1\x06\x02\x10\x01P\x0b\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.core.base_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037io.envoyproxy.envoy.api.v2.coreB\tBaseProtoP\001Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\362\230\376\217\005\026\022\024envoy.config.core.v3\272\200\310\321\006\002\020\001'
  _NODE.fields_by_name['build_version']._options = None
  _NODE.fields_by_name['build_version']._serialized_options = b'\030\001'
  _METADATA_FILTERMETADATAENTRY._options = None
  _METADATA_FILTERMETADATAENTRY._serialized_options = b'8\001'
  _RUNTIMEUINT32.fields_by_name['runtime_key']._options = None
  _RUNTIMEUINT32.fields_by_name['runtime_key']._serialized_options = b'\372B\004r\002 \001'
  _RUNTIMEDOUBLE.fields_by_name['runtime_key']._options = None
  _RUNTIMEDOUBLE.fields_by_name['runtime_key']._serialized_options = b'\372B\004r\002 \001'
  _RUNTIMEFEATUREFLAG.fields_by_name['default_value']._options = None
  _RUNTIMEFEATUREFLAG.fields_by_name['default_value']._serialized_options = b'\372B\005\212\001\002\020\001'
  _RUNTIMEFEATUREFLAG.fields_by_name['runtime_key']._options = None
  _RUNTIMEFEATUREFLAG.fields_by_name['runtime_key']._serialized_options = b'\372B\004r\002 \001'
  _HEADERVALUE.fields_by_name['key']._options = None
  _HEADERVALUE.fields_by_name['key']._serialized_options = b'\372B\016r\014 \001(\200\200\001\300\001\001\310\001\000'
  _HEADERVALUE.fields_by_name['value']._options = None
  _HEADERVALUE.fields_by_name['value']._serialized_options = b'\372B\014r\n(\200\200\001\300\001\002\310\001\000'
  _HEADERVALUEOPTION.fields_by_name['header']._options = None
  _HEADERVALUEOPTION.fields_by_name['header']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DATASOURCE.oneofs_by_name['specifier']._options = None
  _DATASOURCE.oneofs_by_name['specifier']._serialized_options = b'\370B\001'
  _DATASOURCE.fields_by_name['filename']._options = None
  _DATASOURCE.fields_by_name['filename']._serialized_options = b'\372B\004r\002 \001'
  _DATASOURCE.fields_by_name['inline_bytes']._options = None
  _DATASOURCE.fields_by_name['inline_bytes']._serialized_options = b'\372B\004z\002\020\001'
  _DATASOURCE.fields_by_name['inline_string']._options = None
  _DATASOURCE.fields_by_name['inline_string']._serialized_options = b'\372B\004r\002 \001'
  _REMOTEDATASOURCE.fields_by_name['http_uri']._options = None
  _REMOTEDATASOURCE.fields_by_name['http_uri']._serialized_options = b'\372B\005\212\001\002\020\001'
  _REMOTEDATASOURCE.fields_by_name['sha256']._options = None
  _REMOTEDATASOURCE.fields_by_name['sha256']._serialized_options = b'\372B\004r\002 \001'
  _ASYNCDATASOURCE.oneofs_by_name['specifier']._options = None
  _ASYNCDATASOURCE.oneofs_by_name['specifier']._serialized_options = b'\370B\001'
  _TRANSPORTSOCKET.fields_by_name['name']._options = None
  _TRANSPORTSOCKET.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _TRANSPORTSOCKET.fields_by_name['config']._options = None
  _TRANSPORTSOCKET.fields_by_name['config']._serialized_options = b'\030\001'
  _RUNTIMEFRACTIONALPERCENT.fields_by_name['default_value']._options = None
  _RUNTIMEFRACTIONALPERCENT.fields_by_name['default_value']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_ROUTINGPRIORITY']._serialized_start=2705
  _globals['_ROUTINGPRIORITY']._serialized_end=2745
  _globals['_REQUESTMETHOD']._serialized_start=2748
  _globals['_REQUESTMETHOD']._serialized_end=2885
  _globals['_TRAFFICDIRECTION']._serialized_start=2887
  _globals['_TRAFFICDIRECTION']._serialized_end=2949
  _globals['_LOCALITY']._serialized_start=428
  _globals['_LOCALITY']._serialized_end=486
  _globals['_BUILDVERSION']._serialized_start=488
  _globals['_BUILDVERSION']._serialized_end=591
  _globals['_EXTENSION']._serialized_start=594
  _globals['_EXTENSION']._serialized_end=730
  _globals['_NODE']._serialized_start=733
  _globals['_NODE']._serialized_end=1168
  _globals['_METADATA']._serialized_start=1171
  _globals['_METADATA']._serialized_end=1335
  _globals['_METADATA_FILTERMETADATAENTRY']._serialized_start=1257
  _globals['_METADATA_FILTERMETADATAENTRY']._serialized_end=1335
  _globals['_RUNTIMEUINT32']._serialized_start=1337
  _globals['_RUNTIMEUINT32']._serialized_end=1405
  _globals['_RUNTIMEDOUBLE']._serialized_start=1407
  _globals['_RUNTIMEDOUBLE']._serialized_end=1475
  _globals['_RUNTIMEFEATUREFLAG']._serialized_start=1477
  _globals['_RUNTIMEFEATUREFLAG']._serialized_end=1588
  _globals['_HEADERVALUE']._serialized_start=1590
  _globals['_HEADERVALUE']._serialized_end=1667
  _globals['_HEADERVALUEOPTION']._serialized_start=1669
  _globals['_HEADERVALUEOPTION']._serialized_end=1790
  _globals['_HEADERMAP']._serialized_start=1792
  _globals['_HEADERMAP']._serialized_end=1852
  _globals['_DATASOURCE']._serialized_start=1854
  _globals['_DATASOURCE']._serialized_end=1980
  _globals['_RETRYPOLICY']._serialized_start=1982
  _globals['_RETRYPOLICY']._serialized_end=2106
  _globals['_REMOTEDATASOURCE']._serialized_start=2109
  _globals['_REMOTEDATASOURCE']._serialized_end=2262
  _globals['_ASYNCDATASOURCE']._serialized_start=2265
  _globals['_ASYNCDATASOURCE']._serialized_end=2403
  _globals['_TRANSPORTSOCKET']._serialized_start=2406
  _globals['_TRANSPORTSOCKET']._serialized_end=2554
  _globals['_RUNTIMEFRACTIONALPERCENT']._serialized_start=2556
  _globals['_RUNTIMEFRACTIONALPERCENT']._serialized_end=2667
  _globals['_CONTROLPLANE']._serialized_start=2669
  _globals['_CONTROLPLANE']._serialized_end=2703
# @@protoc_insertion_point(module_scope)
