# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/cluster/v3/outlier_detection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/envoy/config/cluster/v3/outlier_detection.proto\x12\x17\x65nvoy.config.cluster.v3\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x9a\r\n\x10OutlierDetection\x12\x35\n\x0f\x63onsecutive_5xx\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x35\n\x08interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12?\n\x12\x62\x61se_ejection_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x43\n\x14max_ejection_percent\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12H\n\x19\x65nforcing_consecutive_5xx\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12\x45\n\x16\x65nforcing_success_rate\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12@\n\x1asuccess_rate_minimum_hosts\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x41\n\x1bsuccess_rate_request_volume\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12?\n\x19success_rate_stdev_factor\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x41\n\x1b\x63onsecutive_gateway_failure\x18\n \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12T\n%enforcing_consecutive_gateway_failure\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12*\n\"split_external_local_origin_errors\x18\x0c \x01(\x08\x12\x46\n consecutive_local_origin_failure\x18\r \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12Y\n*enforcing_consecutive_local_origin_failure\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12R\n#enforcing_local_origin_success_rate\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12K\n\x1c\x66\x61ilure_percentage_threshold\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12K\n\x1c\x65nforcing_failure_percentage\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12X\n)enforcing_failure_percentage_local_origin\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12\x46\n failure_percentage_minimum_hosts\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12G\n!failure_percentage_request_volume\x18\x14 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12>\n\x11max_ejection_time\x18\x15 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12;\n\x18max_ejection_time_jitter\x18\x16 \x01(\x0b\x32\x19.google.protobuf.Duration\x12O\n+successful_active_health_check_uneject_host\x18\x17 \x01(\x0b\x32\x1a.google.protobuf.BoolValue:,\x9a\xc5\x88\x1e\'\n%envoy.api.v2.cluster.OutlierDetectionB\x92\x01\n%io.envoyproxy.envoy.config.cluster.v3B\x15OutlierDetectionProtoP\x01ZHgithub.com/envoyproxy/go-control-plane/envoy/config/cluster/v3;clusterv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.cluster.v3.outlier_detection_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.envoyproxy.envoy.config.cluster.v3B\025OutlierDetectionProtoP\001ZHgithub.com/envoyproxy/go-control-plane/envoy/config/cluster/v3;clusterv3\272\200\310\321\006\002\020\002'
  _OUTLIERDETECTION.fields_by_name['interval']._options = None
  _OUTLIERDETECTION.fields_by_name['interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _OUTLIERDETECTION.fields_by_name['base_ejection_time']._options = None
  _OUTLIERDETECTION.fields_by_name['base_ejection_time']._serialized_options = b'\372B\005\252\001\002*\000'
  _OUTLIERDETECTION.fields_by_name['max_ejection_percent']._options = None
  _OUTLIERDETECTION.fields_by_name['max_ejection_percent']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIERDETECTION.fields_by_name['enforcing_consecutive_5xx']._options = None
  _OUTLIERDETECTION.fields_by_name['enforcing_consecutive_5xx']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIERDETECTION.fields_by_name['enforcing_success_rate']._options = None
  _OUTLIERDETECTION.fields_by_name['enforcing_success_rate']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIERDETECTION.fields_by_name['enforcing_consecutive_gateway_failure']._options = None
  _OUTLIERDETECTION.fields_by_name['enforcing_consecutive_gateway_failure']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIERDETECTION.fields_by_name['enforcing_consecutive_local_origin_failure']._options = None
  _OUTLIERDETECTION.fields_by_name['enforcing_consecutive_local_origin_failure']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIERDETECTION.fields_by_name['enforcing_local_origin_success_rate']._options = None
  _OUTLIERDETECTION.fields_by_name['enforcing_local_origin_success_rate']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIERDETECTION.fields_by_name['failure_percentage_threshold']._options = None
  _OUTLIERDETECTION.fields_by_name['failure_percentage_threshold']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIERDETECTION.fields_by_name['enforcing_failure_percentage']._options = None
  _OUTLIERDETECTION.fields_by_name['enforcing_failure_percentage']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIERDETECTION.fields_by_name['enforcing_failure_percentage_local_origin']._options = None
  _OUTLIERDETECTION.fields_by_name['enforcing_failure_percentage_local_origin']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIERDETECTION.fields_by_name['max_ejection_time']._options = None
  _OUTLIERDETECTION.fields_by_name['max_ejection_time']._serialized_options = b'\372B\005\252\001\002*\000'
  _OUTLIERDETECTION._options = None
  _OUTLIERDETECTION._serialized_options = b'\232\305\210\036\'\n%envoy.api.v2.cluster.OutlierDetection'
  _globals['_OUTLIERDETECTION']._serialized_start=232
  _globals['_OUTLIERDETECTION']._serialized_end=1922
# @@protoc_insertion_point(module_scope)
