# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/common/async_files/v3/async_file_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?envoy/extensions/common/async_files/v3/async_file_manager.proto\x12&envoy.extensions.common.async_files.v3\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xc9\x01\n\x16\x41syncFileManagerConfig\x12\n\n\x02id\x18\x01 \x01(\t\x12`\n\x0bthread_pool\x18\x02 \x01(\x0b\x32I.envoy.extensions.common.async_files.v3.AsyncFileManagerConfig.ThreadPoolH\x00\x1a,\n\nThreadPool\x12\x1e\n\x0cthread_count\x18\x01 \x01(\rB\x08\xfa\x42\x05*\x03\x18\x80\x08\x42\x13\n\x0cmanager_type\x12\x03\xf8\x42\x01\x42\xbc\x01\n4io.envoyproxy.envoy.extensions.common.async_files.v3B\x15\x41syncFileManagerProtoP\x01Z[github.com/envoyproxy/go-control-plane/envoy/extensions/common/async_files/v3;async_filesv3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.common.async_files.v3.async_file_manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n4io.envoyproxy.envoy.extensions.common.async_files.v3B\025AsyncFileManagerProtoP\001Z[github.com/envoyproxy/go-control-plane/envoy/extensions/common/async_files/v3;async_filesv3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _ASYNCFILEMANAGERCONFIG_THREADPOOL.fields_by_name['thread_count']._options = None
  _ASYNCFILEMANAGERCONFIG_THREADPOOL.fields_by_name['thread_count']._serialized_options = b'\372B\005*\003\030\200\010'
  _ASYNCFILEMANAGERCONFIG.oneofs_by_name['manager_type']._options = None
  _ASYNCFILEMANAGERCONFIG.oneofs_by_name['manager_type']._serialized_options = b'\370B\001'
  _globals['_ASYNCFILEMANAGERCONFIG']._serialized_start=197
  _globals['_ASYNCFILEMANAGERCONFIG']._serialized_end=398
  _globals['_ASYNCFILEMANAGERCONFIG_THREADPOOL']._serialized_start=333
  _globals['_ASYNCFILEMANAGERCONFIG_THREADPOOL']._serialized_end=377
# @@protoc_insertion_point(module_scope)
