# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/local_ratelimit/v3/local_rate_limit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.extensions.common.ratelimit.v3 import ratelimit_pb2 as envoy_dot_extensions_dot_common_dot_ratelimit_dot_v3_dot_ratelimit__pb2
from envoy.type.v3 import http_status_pb2 as envoy_dot_type_dot_v3_dot_http__status__pb2
from envoy.type.v3 import token_bucket_pb2 as envoy_dot_type_dot_v3_dot_token__bucket__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGenvoy/extensions/filters/http/local_ratelimit/v3/local_rate_limit.proto\x12\x30\x65nvoy.extensions.filters.http.local_ratelimit.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x34\x65nvoy/extensions/common/ratelimit/v3/ratelimit.proto\x1a\x1f\x65nvoy/type/v3/http_status.proto\x1a envoy/type/v3/token_bucket.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xb9\x07\n\x0eLocalRateLimit\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12)\n\x06status\x18\x02 \x01(\x0b\x32\x19.envoy.type.v3.HttpStatus\x12\x30\n\x0ctoken_bucket\x18\x03 \x01(\x0b\x32\x1a.envoy.type.v3.TokenBucket\x12\x46\n\x0e\x66ilter_enabled\x18\x04 \x01(\x0b\x32..envoy.config.core.v3.RuntimeFractionalPercent\x12G\n\x0f\x66ilter_enforced\x18\x05 \x01(\x0b\x32..envoy.config.core.v3.RuntimeFractionalPercent\x12\x63\n(request_headers_to_add_when_not_enforced\x18\n \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOptionB\x08\xfa\x42\x05\x92\x01\x02\x10\n\x12R\n\x17response_headers_to_add\x18\x06 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOptionB\x08\xfa\x42\x05\x92\x01\x02\x10\n\x12S\n\x0b\x64\x65scriptors\x18\x08 \x03(\x0b\x32>.envoy.extensions.common.ratelimit.v3.LocalRateLimitDescriptor\x12\x16\n\x05stage\x18\t \x01(\rB\x07\xfa\x42\x04*\x02\x18\n\x12\x32\n*local_rate_limit_per_downstream_connection\x18\x0b \x01(\x08\x12o\n\x1a\x65nable_x_ratelimit_headers\x18\x0c \x01(\x0e\x32\x41.envoy.extensions.common.ratelimit.v3.XRateLimitHeadersRFCVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12[\n\x0evh_rate_limits\x18\r \x01(\x0e\x32\x39.envoy.extensions.common.ratelimit.v3.VhRateLimitsOptionsB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12G\n#always_consume_default_token_bucket\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\"rate_limited_as_resource_exhausted\x18\x0f \x01(\x08\x42\xca\x01\n>io.envoyproxy.envoy.extensions.filters.http.local_ratelimit.v3B\x13LocalRateLimitProtoP\x01Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/local_ratelimit/v3;local_ratelimitv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.local_ratelimit.v3.local_rate_limit_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>io.envoyproxy.envoy.extensions.filters.http.local_ratelimit.v3B\023LocalRateLimitProtoP\001Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/local_ratelimit/v3;local_ratelimitv3\272\200\310\321\006\002\020\002'
  _LOCALRATELIMIT.fields_by_name['stat_prefix']._options = None
  _LOCALRATELIMIT.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002\020\001'
  _LOCALRATELIMIT.fields_by_name['request_headers_to_add_when_not_enforced']._options = None
  _LOCALRATELIMIT.fields_by_name['request_headers_to_add_when_not_enforced']._serialized_options = b'\372B\005\222\001\002\020\n'
  _LOCALRATELIMIT.fields_by_name['response_headers_to_add']._options = None
  _LOCALRATELIMIT.fields_by_name['response_headers_to_add']._serialized_options = b'\372B\005\222\001\002\020\n'
  _LOCALRATELIMIT.fields_by_name['stage']._options = None
  _LOCALRATELIMIT.fields_by_name['stage']._serialized_options = b'\372B\004*\002\030\n'
  _LOCALRATELIMIT.fields_by_name['enable_x_ratelimit_headers']._options = None
  _LOCALRATELIMIT.fields_by_name['enable_x_ratelimit_headers']._serialized_options = b'\372B\005\202\001\002\020\001'
  _LOCALRATELIMIT.fields_by_name['vh_rate_limits']._options = None
  _LOCALRATELIMIT.fields_by_name['vh_rate_limits']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_LOCALRATELIMIT']._serialized_start=368
  _globals['_LOCALRATELIMIT']._serialized_end=1321
# @@protoc_insertion_point(module_scope)
