# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/tracers/opentelemetry/resource_detectors/v3/dynatrace_resource_detector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n^envoy/extensions/tracers/opentelemetry/resource_detectors/v3/dynatrace_resource_detector.proto\x12<envoy.extensions.tracers.opentelemetry.resource_detectors.v3\x1a\x1dudpa/annotations/status.proto\"!\n\x1f\x44ynatraceResourceDetectorConfigB\xf0\x01\nJio.envoyproxy.envoy.extensions.tracers.opentelemetry.resource_detectors.v3B\x1e\x44ynatraceResourceDetectorProtoP\x01Zxgithub.com/envoyproxy/go-control-plane/envoy/extensions/tracers/opentelemetry/resource_detectors/v3;resource_detectorsv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.tracers.opentelemetry.resource_detectors.v3.dynatrace_resource_detector_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nJio.envoyproxy.envoy.extensions.tracers.opentelemetry.resource_detectors.v3B\036DynatraceResourceDetectorProtoP\001Zxgithub.com/envoyproxy/go-control-plane/envoy/extensions/tracers/opentelemetry/resource_detectors/v3;resource_detectorsv3\272\200\310\321\006\002\020\002'
  _globals['_DYNATRACERESOURCEDETECTORCONFIG']._serialized_start=191
  _globals['_DYNATRACERESOURCEDETECTORCONFIG']._serialized_end=224
# @@protoc_insertion_point(module_scope)
