# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/path/rewrite/uri_template/v3/uri_template_rewrite.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHenvoy/extensions/path/rewrite/uri_template/v3/uri_template_rewrite.proto\x12-envoy.extensions.path.rewrite.uri_template.v3\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"E\n\x18UriTemplateRewriteConfig\x12)\n\x15path_template_rewrite\x18\x01 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\x18\x80\x02\x42\xc5\x01\n;io.envoyproxy.envoy.extensions.path.rewrite.uri_template.v3B\x17UriTemplateRewriteProtoP\x01Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/path/rewrite/uri_template/v3;uri_templatev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.path.rewrite.uri_template.v3.uri_template_rewrite_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n;io.envoyproxy.envoy.extensions.path.rewrite.uri_template.v3B\027UriTemplateRewriteProtoP\001Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/path/rewrite/uri_template/v3;uri_templatev3\272\200\310\321\006\002\020\002'
  _URITEMPLATEREWRITECONFIG.fields_by_name['path_template_rewrite']._options = None
  _URITEMPLATEREWRITECONFIG.fields_by_name['path_template_rewrite']._serialized_options = b'\372B\007r\005\020\001\030\200\002'
  _globals['_URITEMPLATEREWRITECONFIG']._serialized_start=179
  _globals['_URITEMPLATEREWRITECONFIG']._serialized_end=248
# @@protoc_insertion_point(module_scope)
