# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/common/ratelimit/v3/ratelimit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.v3 import ratelimit_unit_pb2 as envoy_dot_type_dot_v3_dot_ratelimit__unit__pb2
from envoy.type.v3 import token_bucket_pb2 as envoy_dot_type_dot_v3_dot_token__bucket__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4envoy/extensions/common/ratelimit/v3/ratelimit.proto\x12$envoy.extensions.common.ratelimit.v3\x1a\"envoy/type/v3/ratelimit_unit.proto\x1a envoy/type/v3/token_bucket.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xd6\x03\n\x13RateLimitDescriptor\x12Z\n\x07\x65ntries\x18\x01 \x03(\x0b\x32?.envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.EntryB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12Z\n\x05limit\x18\x02 \x01(\x0b\x32K.envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.RateLimitOverride\x1an\n\x05\x45ntry\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x16\n\x05value\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01:7\x9a\xc5\x88\x1e\x32\n0envoy.api.v2.ratelimit.RateLimitDescriptor.Entry\x1a\x64\n\x11RateLimitOverride\x12\x19\n\x11requests_per_unit\x18\x01 \x01(\r\x12\x34\n\x04unit\x18\x02 \x01(\x0e\x32\x1c.envoy.type.v3.RateLimitUnitB\x08\xfa\x42\x05\x82\x01\x02\x10\x01:1\x9a\xc5\x88\x1e,\n*envoy.api.v2.ratelimit.RateLimitDescriptor\"\xb2\x01\n\x18LocalRateLimitDescriptor\x12Z\n\x07\x65ntries\x18\x01 \x03(\x0b\x32?.envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.EntryB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12:\n\x0ctoken_bucket\x18\x02 \x01(\x0b\x32\x1a.envoy.type.v3.TokenBucketB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01*<\n\x1bXRateLimitHeadersRFCVersion\x12\x07\n\x03OFF\x10\x00\x12\x14\n\x10\x44RAFT_VERSION_03\x10\x01*<\n\x13VhRateLimitsOptions\x12\x0c\n\x08OVERRIDE\x10\x00\x12\x0b\n\x07INCLUDE\x10\x01\x12\n\n\x06IGNORE\x10\x02\x42\xa7\x01\n2io.envoyproxy.envoy.extensions.common.ratelimit.v3B\x0eRatelimitProtoP\x01ZWgithub.com/envoyproxy/go-control-plane/envoy/extensions/common/ratelimit/v3;ratelimitv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.common.ratelimit.v3.ratelimit_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n2io.envoyproxy.envoy.extensions.common.ratelimit.v3B\016RatelimitProtoP\001ZWgithub.com/envoyproxy/go-control-plane/envoy/extensions/common/ratelimit/v3;ratelimitv3\272\200\310\321\006\002\020\002'
  _RATELIMITDESCRIPTOR_ENTRY.fields_by_name['key']._options = None
  _RATELIMITDESCRIPTOR_ENTRY.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _RATELIMITDESCRIPTOR_ENTRY.fields_by_name['value']._options = None
  _RATELIMITDESCRIPTOR_ENTRY.fields_by_name['value']._serialized_options = b'\372B\004r\002\020\001'
  _RATELIMITDESCRIPTOR_ENTRY._options = None
  _RATELIMITDESCRIPTOR_ENTRY._serialized_options = b'\232\305\210\0362\n0envoy.api.v2.ratelimit.RateLimitDescriptor.Entry'
  _RATELIMITDESCRIPTOR_RATELIMITOVERRIDE.fields_by_name['unit']._options = None
  _RATELIMITDESCRIPTOR_RATELIMITOVERRIDE.fields_by_name['unit']._serialized_options = b'\372B\005\202\001\002\020\001'
  _RATELIMITDESCRIPTOR.fields_by_name['entries']._options = None
  _RATELIMITDESCRIPTOR.fields_by_name['entries']._serialized_options = b'\372B\005\222\001\002\010\001'
  _RATELIMITDESCRIPTOR._options = None
  _RATELIMITDESCRIPTOR._serialized_options = b'\232\305\210\036,\n*envoy.api.v2.ratelimit.RateLimitDescriptor'
  _LOCALRATELIMITDESCRIPTOR.fields_by_name['entries']._options = None
  _LOCALRATELIMITDESCRIPTOR.fields_by_name['entries']._serialized_options = b'\372B\005\222\001\002\010\001'
  _LOCALRATELIMITDESCRIPTOR.fields_by_name['token_bucket']._options = None
  _LOCALRATELIMITDESCRIPTOR.fields_by_name['token_bucket']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_XRATELIMITHEADERSRFCVERSION']._serialized_start=909
  _globals['_XRATELIMITHEADERSRFCVERSION']._serialized_end=969
  _globals['_VHRATELIMITSOPTIONS']._serialized_start=971
  _globals['_VHRATELIMITSOPTIONS']._serialized_end=1031
  _globals['_RATELIMITDESCRIPTOR']._serialized_start=256
  _globals['_RATELIMITDESCRIPTOR']._serialized_end=726
  _globals['_RATELIMITDESCRIPTOR_ENTRY']._serialized_start=463
  _globals['_RATELIMITDESCRIPTOR_ENTRY']._serialized_end=573
  _globals['_RATELIMITDESCRIPTOR_RATELIMITOVERRIDE']._serialized_start=575
  _globals['_RATELIMITDESCRIPTOR_RATELIMITOVERRIDE']._serialized_end=675
  _globals['_LOCALRATELIMITDESCRIPTOR']._serialized_start=729
  _globals['_LOCALRATELIMITDESCRIPTOR']._serialized_end=907
# @@protoc_insertion_point(module_scope)
