# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/tap/v2alpha/transport.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.data.tap.v2alpha import common_pb2 as envoy_dot_data_dot_tap_dot_v2alpha_dot_common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&envoy/data/tap/v2alpha/transport.proto\x12\x16\x65nvoy.data.tap.v2alpha\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a#envoy/data/tap/v2alpha/common.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dudpa/annotations/status.proto\"s\n\nConnection\x12\x31\n\rlocal_address\x18\x02 \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\x12\x32\n\x0eremote_address\x18\x03 \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\"\x89\x03\n\x0bSocketEvent\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x04read\x18\x02 \x01(\x0b\x32(.envoy.data.tap.v2alpha.SocketEvent.ReadH\x00\x12:\n\x05write\x18\x03 \x01(\x0b\x32).envoy.data.tap.v2alpha.SocketEvent.WriteH\x00\x12<\n\x06\x63losed\x18\x04 \x01(\x0b\x32*.envoy.data.tap.v2alpha.SocketEvent.ClosedH\x00\x1a\x32\n\x04Read\x12*\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1c.envoy.data.tap.v2alpha.Body\x1aG\n\x05Write\x12*\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1c.envoy.data.tap.v2alpha.Body\x12\x12\n\nend_stream\x18\x02 \x01(\x08\x1a\x08\n\x06\x43losedB\x10\n\x0e\x65vent_selector\"\xc5\x01\n\x13SocketBufferedTrace\x12\x10\n\x08trace_id\x18\x01 \x01(\x04\x12\x36\n\nconnection\x18\x02 \x01(\x0b\x32\".envoy.data.tap.v2alpha.Connection\x12\x33\n\x06\x65vents\x18\x03 \x03(\x0b\x32#.envoy.data.tap.v2alpha.SocketEvent\x12\x16\n\x0eread_truncated\x18\x04 \x01(\x08\x12\x17\n\x0fwrite_truncated\x18\x05 \x01(\x08\"\xaf\x01\n\x1aSocketStreamedTraceSegment\x12\x10\n\x08trace_id\x18\x01 \x01(\x04\x12\x38\n\nconnection\x18\x02 \x01(\x0b\x32\".envoy.data.tap.v2alpha.ConnectionH\x00\x12\x34\n\x05\x65vent\x18\x03 \x01(\x0b\x32#.envoy.data.tap.v2alpha.SocketEventH\x00\x42\x0f\n\rmessage_pieceB\x7f\n$io.envoyproxy.envoy.data.tap.v2alphaB\x0eTransportProtoP\x01Z=github.com/envoyproxy/go-control-plane/envoy/data/tap/v2alpha\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.data.tap.v2alpha.transport_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$io.envoyproxy.envoy.data.tap.v2alphaB\016TransportProtoP\001Z=github.com/envoyproxy/go-control-plane/envoy/data/tap/v2alpha\272\200\310\321\006\002\020\001'
  _globals['_CONNECTION']._serialized_start=200
  _globals['_CONNECTION']._serialized_end=315
  _globals['_SOCKETEVENT']._serialized_start=318
  _globals['_SOCKETEVENT']._serialized_end=711
  _globals['_SOCKETEVENT_READ']._serialized_start=560
  _globals['_SOCKETEVENT_READ']._serialized_end=610
  _globals['_SOCKETEVENT_WRITE']._serialized_start=612
  _globals['_SOCKETEVENT_WRITE']._serialized_end=683
  _globals['_SOCKETEVENT_CLOSED']._serialized_start=685
  _globals['_SOCKETEVENT_CLOSED']._serialized_end=693
  _globals['_SOCKETBUFFEREDTRACE']._serialized_start=714
  _globals['_SOCKETBUFFEREDTRACE']._serialized_end=911
  _globals['_SOCKETSTREAMEDTRACESEGMENT']._serialized_start=914
  _globals['_SOCKETSTREAMEDTRACESEGMENT']._serialized_end=1089
# @@protoc_insertion_point(module_scope)
