# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/event_reporting/v3/event_reporting_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>envoy/service/event_reporting/v3/event_reporting_service.proto\x12 envoy.service.event_reporting.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x19google/protobuf/any.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xed\x02\n\x13StreamEventsRequest\x12T\n\nidentifier\x18\x01 \x01(\x0b\x32@.envoy.service.event_reporting.v3.StreamEventsRequest.Identifier\x12.\n\x06\x65vents\x18\x02 \x03(\x0b\x32\x14.google.protobuf.AnyB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\x8d\x01\n\nIdentifier\x12\x32\n\x04node\x18\x01 \x01(\x0b\x32\x1a.envoy.config.core.v3.NodeB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:K\x9a\xc5\x88\x1e\x46\nDenvoy.service.event_reporting.v2alpha.StreamEventsRequest.Identifier:@\x9a\xc5\x88\x1e;\n9envoy.service.event_reporting.v2alpha.StreamEventsRequest\"Y\n\x14StreamEventsResponse:A\x9a\xc5\x88\x1e<\n:envoy.service.event_reporting.v2alpha.StreamEventsResponse2\x9d\x01\n\x15\x45ventReportingService\x12\x83\x01\n\x0cStreamEvents\x12\x35.envoy.service.event_reporting.v3.StreamEventsRequest\x1a\x36.envoy.service.event_reporting.v3.StreamEventsResponse\"\x00(\x01\x30\x01\x42\xb1\x01\n.io.envoyproxy.envoy.service.event_reporting.v3B\x1a\x45ventReportingServiceProtoP\x01ZYgithub.com/envoyproxy/go-control-plane/envoy/service/event_reporting/v3;event_reportingv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.event_reporting.v3.event_reporting_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n.io.envoyproxy.envoy.service.event_reporting.v3B\032EventReportingServiceProtoP\001ZYgithub.com/envoyproxy/go-control-plane/envoy/service/event_reporting/v3;event_reportingv3\272\200\310\321\006\002\020\002'
  _STREAMEVENTSREQUEST_IDENTIFIER.fields_by_name['node']._options = None
  _STREAMEVENTSREQUEST_IDENTIFIER.fields_by_name['node']._serialized_options = b'\372B\005\212\001\002\020\001'
  _STREAMEVENTSREQUEST_IDENTIFIER._options = None
  _STREAMEVENTSREQUEST_IDENTIFIER._serialized_options = b'\232\305\210\036F\nDenvoy.service.event_reporting.v2alpha.StreamEventsRequest.Identifier'
  _STREAMEVENTSREQUEST.fields_by_name['events']._options = None
  _STREAMEVENTSREQUEST.fields_by_name['events']._serialized_options = b'\372B\005\222\001\002\010\001'
  _STREAMEVENTSREQUEST._options = None
  _STREAMEVENTSREQUEST._serialized_options = b'\232\305\210\036;\n9envoy.service.event_reporting.v2alpha.StreamEventsRequest'
  _STREAMEVENTSRESPONSE._options = None
  _STREAMEVENTSRESPONSE._serialized_options = b'\232\305\210\036<\n:envoy.service.event_reporting.v2alpha.StreamEventsResponse'
  _globals['_STREAMEVENTSREQUEST']._serialized_start=252
  _globals['_STREAMEVENTSREQUEST']._serialized_end=617
  _globals['_STREAMEVENTSREQUEST_IDENTIFIER']._serialized_start=410
  _globals['_STREAMEVENTSREQUEST_IDENTIFIER']._serialized_end=551
  _globals['_STREAMEVENTSRESPONSE']._serialized_start=619
  _globals['_STREAMEVENTSRESPONSE']._serialized_end=708
  _globals['_EVENTREPORTINGSERVICE']._serialized_start=711
  _globals['_EVENTREPORTINGSERVICE']._serialized_end=868
# @@protoc_insertion_point(module_scope)
