# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v2alpha/clusters.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.admin.v2alpha import metrics_pb2 as envoy_dot_admin_dot_v2alpha_dot_metrics__pb2
from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import health_check_pb2 as envoy_dot_api_dot_v2_dot_core_dot_health__check__pb2
from envoy.type import percent_pb2 as envoy_dot_type_dot_percent__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"envoy/admin/v2alpha/clusters.proto\x12\x13\x65nvoy.admin.v2alpha\x1a!envoy/admin/v2alpha/metrics.proto\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a$envoy/api/v2/core/health_check.proto\x1a\x18\x65nvoy/type/percent.proto\x1a\x1dudpa/annotations/status.proto\"H\n\x08\x43lusters\x12<\n\x10\x63luster_statuses\x18\x01 \x03(\x0b\x32\".envoy.admin.v2alpha.ClusterStatus\"\xf5\x01\n\rClusterStatus\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\radded_via_api\x18\x02 \x01(\x08\x12<\n\x1fsuccess_rate_ejection_threshold\x18\x03 \x01(\x0b\x32\x13.envoy.type.Percent\x12\x36\n\rhost_statuses\x18\x04 \x03(\x0b\x32\x1f.envoy.admin.v2alpha.HostStatus\x12I\n,local_origin_success_rate_ejection_threshold\x18\x05 \x01(\x0b\x32\x13.envoy.type.Percent\"\xef\x02\n\nHostStatus\x12+\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\x12\x30\n\x05stats\x18\x02 \x03(\x0b\x32!.envoy.admin.v2alpha.SimpleMetric\x12<\n\rhealth_status\x18\x03 \x01(\x0b\x32%.envoy.admin.v2alpha.HostHealthStatus\x12)\n\x0csuccess_rate\x18\x04 \x01(\x0b\x32\x13.envoy.type.Percent\x12\x0e\n\x06weight\x18\x05 \x01(\r\x12\x10\n\x08hostname\x18\x06 \x01(\t\x12\x10\n\x08priority\x18\x07 \x01(\r\x12\x36\n\x19local_origin_success_rate\x18\x08 \x01(\x0b\x32\x13.envoy.type.Percent\x12-\n\x08locality\x18\t \x01(\x0b\x32\x1b.envoy.api.v2.core.Locality\"\xf2\x01\n\x10HostHealthStatus\x12\"\n\x1a\x66\x61iled_active_health_check\x18\x01 \x01(\x08\x12\x1c\n\x14\x66\x61iled_outlier_check\x18\x02 \x01(\x08\x12$\n\x1c\x66\x61iled_active_degraded_check\x18\x04 \x01(\x08\x12\x1f\n\x17pending_dynamic_removal\x18\x05 \x01(\x08\x12\x19\n\x11pending_active_hc\x18\x06 \x01(\x08\x12:\n\x11\x65\x64s_health_status\x18\x03 \x01(\x0e\x32\x1f.envoy.api.v2.core.HealthStatusBx\n!io.envoyproxy.envoy.admin.v2alphaB\rClustersProtoP\x01Z:github.com/envoyproxy/go-control-plane/envoy/admin/v2alpha\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.admin.v2alpha.clusters_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!io.envoyproxy.envoy.admin.v2alphaB\rClustersProtoP\001Z:github.com/envoyproxy/go-control-plane/envoy/admin/v2alpha\272\200\310\321\006\002\020\001'
  _globals['_CLUSTERS']._serialized_start=252
  _globals['_CLUSTERS']._serialized_end=324
  _globals['_CLUSTERSTATUS']._serialized_start=327
  _globals['_CLUSTERSTATUS']._serialized_end=572
  _globals['_HOSTSTATUS']._serialized_start=575
  _globals['_HOSTSTATUS']._serialized_end=942
  _globals['_HOSTHEALTHSTATUS']._serialized_start=945
  _globals['_HOSTHEALTHSTATUS']._serialized_end=1187
# @@protoc_insertion_point(module_scope)
