# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/ext_proc/v3/ext_proc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.common.mutation_rules.v3 import mutation_rules_pb2 as envoy_dot_config_dot_common_dot_mutation__rules_dot_v3_dot_mutation__rules__pb2
from envoy.config.core.v3 import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2
from envoy.extensions.filters.http.ext_proc.v3 import processing_mode_pb2 as envoy_dot_extensions_dot_filters_dot_http_dot_ext__proc_dot_v3_dot_processing__mode__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8envoy/extensions/filters/http/ext_proc/v3/ext_proc.proto\x12)envoy.extensions.filters.http.ext_proc.v3\x1a:envoy/config/common/mutation_rules/v3/mutation_rules.proto\x1a\'envoy/config/core/v3/grpc_service.proto\x1a?envoy/extensions/filters/http/ext_proc/v3/processing_mode.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xf5\x05\n\x11\x45xternalProcessor\x12\x41\n\x0cgrpc_service\x18\x01 \x01(\x0b\x32!.envoy.config.core.v3.GrpcServiceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1a\n\x12\x66\x61ilure_mode_allow\x18\x02 \x01(\x08\x12R\n\x0fprocessing_mode\x18\x03 \x01(\x0b\x32\x39.envoy.extensions.filters.http.ext_proc.v3.ProcessingMode\x12\x12\n\nasync_mode\x18\x04 \x01(\x08\x12\x1a\n\x12request_attributes\x18\x05 \x03(\t\x12\x1b\n\x13response_attributes\x18\x06 \x03(\t\x12\x41\n\x0fmessage_timeout\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationB\r\xfa\x42\n\xaa\x01\x07\"\x03\x08\x90\x1c\x32\x00\x12\x13\n\x0bstat_prefix\x18\x08 \x01(\t\x12R\n\x0emutation_rules\x18\t \x01(\x0b\x32:.envoy.config.common.mutation_rules.v3.HeaderMutationRules\x12\x45\n\x13max_message_timeout\x18\n \x01(\x0b\x32\x19.google.protobuf.DurationB\r\xfa\x42\n\xaa\x01\x07\"\x03\x08\x90\x1c\x32\x00\x12!\n\x19\x64isable_clear_route_cache\x18\x0b \x01(\x08\x12W\n\rforward_rules\x18\x0c \x01(\x0b\x32@.envoy.extensions.filters.http.ext_proc.v3.HeaderForwardingRules\x12\x30\n\x0f\x66ilter_metadata\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x1b\n\x13\x61llow_mode_override\x18\x0e \x01(\x08\x12\"\n\x1a\x64isable_immediate_response\x18\x0f \x01(\x08\"\xa0\x01\n\x15HeaderForwardingRules\x12\x41\n\x0f\x61llowed_headers\x18\x01 \x01(\x0b\x32(.envoy.type.matcher.v3.ListStringMatcher\x12\x44\n\x12\x64isallowed_headers\x18\x02 \x01(\x0b\x32(.envoy.type.matcher.v3.ListStringMatcher\"\x91\x01\n\x0f\x45xtProcPerRoute\x12\x1b\n\x08\x64isabled\x18\x01 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12P\n\toverrides\x18\x02 \x01(\x0b\x32;.envoy.extensions.filters.http.ext_proc.v3.ExtProcOverridesH\x00\x42\x0f\n\x08override\x12\x03\xf8\x42\x01\"\xec\x01\n\x10\x45xtProcOverrides\x12R\n\x0fprocessing_mode\x18\x01 \x01(\x0b\x32\x39.envoy.extensions.filters.http.ext_proc.v3.ProcessingMode\x12\x12\n\nasync_mode\x18\x02 \x01(\x08\x12\x1a\n\x12request_attributes\x18\x03 \x03(\t\x12\x1b\n\x13response_attributes\x18\x04 \x03(\t\x12\x37\n\x0cgrpc_service\x18\x05 \x01(\x0b\x32!.envoy.config.core.v3.GrpcServiceB\xae\x01\n7io.envoyproxy.envoy.extensions.filters.http.ext_proc.v3B\x0c\x45xtProcProtoP\x01Z[github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/ext_proc/v3;ext_procv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.ext_proc.v3.ext_proc_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7io.envoyproxy.envoy.extensions.filters.http.ext_proc.v3B\014ExtProcProtoP\001Z[github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/ext_proc/v3;ext_procv3\272\200\310\321\006\002\020\002'
  _EXTERNALPROCESSOR.fields_by_name['grpc_service']._options = None
  _EXTERNALPROCESSOR.fields_by_name['grpc_service']._serialized_options = b'\372B\005\212\001\002\020\001'
  _EXTERNALPROCESSOR.fields_by_name['message_timeout']._options = None
  _EXTERNALPROCESSOR.fields_by_name['message_timeout']._serialized_options = b'\372B\n\252\001\007\"\003\010\220\0342\000'
  _EXTERNALPROCESSOR.fields_by_name['max_message_timeout']._options = None
  _EXTERNALPROCESSOR.fields_by_name['max_message_timeout']._serialized_options = b'\372B\n\252\001\007\"\003\010\220\0342\000'
  _EXTPROCPERROUTE.oneofs_by_name['override']._options = None
  _EXTPROCPERROUTE.oneofs_by_name['override']._serialized_options = b'\370B\001'
  _EXTPROCPERROUTE.fields_by_name['disabled']._options = None
  _EXTPROCPERROUTE.fields_by_name['disabled']._serialized_options = b'\372B\004j\002\010\001'
  _globals['_EXTERNALPROCESSOR']._serialized_start=424
  _globals['_EXTERNALPROCESSOR']._serialized_end=1181
  _globals['_HEADERFORWARDINGRULES']._serialized_start=1184
  _globals['_HEADERFORWARDINGRULES']._serialized_end=1344
  _globals['_EXTPROCPERROUTE']._serialized_start=1347
  _globals['_EXTPROCPERROUTE']._serialized_end=1492
  _globals['_EXTPROCOVERRIDES']._serialized_start=1495
  _globals['_EXTPROCOVERRIDES']._serialized_end=1731
# @@protoc_insertion_point(module_scope)
