# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/header_to_metadata/v3/header_to_metadata.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher.v3 import regex_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_regex__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLenvoy/extensions/filters/http/header_to_metadata/v3/header_to_metadata.proto\x12\x33\x65nvoy.extensions.filters.http.header_to_metadata.v3\x1a!envoy/type/matcher/v3/regex.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xe7\t\n\x06\x43onfig\x12W\n\rrequest_rules\x18\x01 \x03(\x0b\x32@.envoy.extensions.filters.http.header_to_metadata.v3.Config.Rule\x12X\n\x0eresponse_rules\x18\x02 \x03(\x0b\x32@.envoy.extensions.filters.http.header_to_metadata.v3.Config.Rule\x1a\xc7\x03\n\x0cKeyValuePair\x12\x1a\n\x12metadata_namespace\x18\x01 \x01(\t\x12\x14\n\x03key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12!\n\x05value\x18\x03 \x01(\tB\x12\xf2\x98\xfe\x8f\x05\x0c\x12\nvalue_type\x12_\n\x13regex_value_rewrite\x18\x06 \x01(\x0b\x32..envoy.type.matcher.v3.RegexMatchAndSubstituteB\x12\xf2\x98\xfe\x8f\x05\x0c\x12\nvalue_type\x12]\n\x04type\x18\x04 \x01(\x0e\x32\x45.envoy.extensions.filters.http.header_to_metadata.v3.Config.ValueTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12W\n\x06\x65ncode\x18\x05 \x01(\x0e\x32G.envoy.extensions.filters.http.header_to_metadata.v3.Config.ValueEncode:I\x9a\xc5\x88\x1e\x44\nBenvoy.config.filter.http.header_to_metadata.v2.Config.KeyValuePair\x1a\xc3\x03\n\x04Rule\x12:\n\x06header\x18\x01 \x01(\tB*\xfa\x42\x08r\x06\xc0\x01\x01\xc8\x01\x00\xf2\x98\xfe\x8f\x05\x19\x12\x17header_cookie_specifier\x12:\n\x06\x63ookie\x18\x05 \x01(\tB*\xfa\x42\x08r\x06\xc0\x01\x01\xc8\x01\x00\xf2\x98\xfe\x8f\x05\x19\x12\x17header_cookie_specifier\x12w\n\x11on_header_present\x18\x02 \x01(\x0b\x32H.envoy.extensions.filters.http.header_to_metadata.v3.Config.KeyValuePairB\x12\xf2\x98\xfe\x8f\x05\x0c\n\non_present\x12w\n\x11on_header_missing\x18\x03 \x01(\x0b\x32H.envoy.extensions.filters.http.header_to_metadata.v3.Config.KeyValuePairB\x12\xf2\x98\xfe\x8f\x05\x0c\n\non_missing\x12\x0e\n\x06remove\x18\x04 \x01(\x08:A\x9a\xc5\x88\x1e<\n:envoy.config.filter.http.header_to_metadata.v2.Config.Rule\"7\n\tValueType\x12\n\n\x06STRING\x10\x00\x12\n\n\x06NUMBER\x10\x01\x12\x12\n\x0ePROTOBUF_VALUE\x10\x02\"#\n\x0bValueEncode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x42\x41SE64\x10\x01:<\x9a\xc5\x88\x1e\x37\n5envoy.config.filter.http.header_to_metadata.v2.ConfigB\xd5\x01\nAio.envoyproxy.envoy.extensions.filters.http.header_to_metadata.v3B\x15HeaderToMetadataProtoP\x01Zogithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/header_to_metadata/v3;header_to_metadatav3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.header_to_metadata.v3.header_to_metadata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nAio.envoyproxy.envoy.extensions.filters.http.header_to_metadata.v3B\025HeaderToMetadataProtoP\001Zogithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/header_to_metadata/v3;header_to_metadatav3\272\200\310\321\006\002\020\002'
  _CONFIG_KEYVALUEPAIR.fields_by_name['key']._options = None
  _CONFIG_KEYVALUEPAIR.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _CONFIG_KEYVALUEPAIR.fields_by_name['value']._options = None
  _CONFIG_KEYVALUEPAIR.fields_by_name['value']._serialized_options = b'\362\230\376\217\005\014\022\nvalue_type'
  _CONFIG_KEYVALUEPAIR.fields_by_name['regex_value_rewrite']._options = None
  _CONFIG_KEYVALUEPAIR.fields_by_name['regex_value_rewrite']._serialized_options = b'\362\230\376\217\005\014\022\nvalue_type'
  _CONFIG_KEYVALUEPAIR.fields_by_name['type']._options = None
  _CONFIG_KEYVALUEPAIR.fields_by_name['type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _CONFIG_KEYVALUEPAIR._options = None
  _CONFIG_KEYVALUEPAIR._serialized_options = b'\232\305\210\036D\nBenvoy.config.filter.http.header_to_metadata.v2.Config.KeyValuePair'
  _CONFIG_RULE.fields_by_name['header']._options = None
  _CONFIG_RULE.fields_by_name['header']._serialized_options = b'\372B\010r\006\300\001\001\310\001\000\362\230\376\217\005\031\022\027header_cookie_specifier'
  _CONFIG_RULE.fields_by_name['cookie']._options = None
  _CONFIG_RULE.fields_by_name['cookie']._serialized_options = b'\372B\010r\006\300\001\001\310\001\000\362\230\376\217\005\031\022\027header_cookie_specifier'
  _CONFIG_RULE.fields_by_name['on_header_present']._options = None
  _CONFIG_RULE.fields_by_name['on_header_present']._serialized_options = b'\362\230\376\217\005\014\n\non_present'
  _CONFIG_RULE.fields_by_name['on_header_missing']._options = None
  _CONFIG_RULE.fields_by_name['on_header_missing']._serialized_options = b'\362\230\376\217\005\014\n\non_missing'
  _CONFIG_RULE._options = None
  _CONFIG_RULE._serialized_options = b'\232\305\210\036<\n:envoy.config.filter.http.header_to_metadata.v2.Config.Rule'
  _CONFIG._options = None
  _CONFIG._serialized_options = b'\232\305\210\0367\n5envoy.config.filter.http.header_to_metadata.v2.Config'
  _globals['_CONFIG']._serialized_start=292
  _globals['_CONFIG']._serialized_end=1547
  _globals['_CONFIG_KEYVALUEPAIR']._serialized_start=482
  _globals['_CONFIG_KEYVALUEPAIR']._serialized_end=937
  _globals['_CONFIG_RULE']._serialized_start=940
  _globals['_CONFIG_RULE']._serialized_end=1391
  _globals['_CONFIG_VALUETYPE']._serialized_start=1393
  _globals['_CONFIG_VALUETYPE']._serialized_end=1448
  _globals['_CONFIG_VALUEENCODE']._serialized_start=1450
  _globals['_CONFIG_VALUEENCODE']._serialized_end=1485
# @@protoc_insertion_point(module_scope)
