# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/network/socket_interface/v3/default_socket_interface.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKenvoy/extensions/network/socket_interface/v3/default_socket_interface.proto\x12,envoy.extensions.network.socket_interface.v3\x1a\x1dudpa/annotations/status.proto\"\x18\n\x16\x44\x65\x66\x61ultSocketInterfaceB\xcb\x01\n:io.envoyproxy.envoy.extensions.network.socket_interface.v3B\x1b\x44\x65\x66\x61ultSocketInterfaceProtoP\x01Zfgithub.com/envoyproxy/go-control-plane/envoy/extensions/network/socket_interface/v3;socket_interfacev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.network.socket_interface.v3.default_socket_interface_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n:io.envoyproxy.envoy.extensions.network.socket_interface.v3B\033DefaultSocketInterfaceProtoP\001Zfgithub.com/envoyproxy/go-control-plane/envoy/extensions/network/socket_interface/v3;socket_interfacev3\272\200\310\321\006\002\020\002'
  _globals['_DEFAULTSOCKETINTERFACE']._serialized_start=156
  _globals['_DEFAULTSOCKETINTERFACE']._serialized_end=180
# @@protoc_insertion_point(module_scope)
