# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/matching/common_inputs/network/v3/network_inputs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGenvoy/extensions/matching/common_inputs/network/v3/network_inputs.proto\x12\x32\x65nvoy.extensions.matching.common_inputs.network.v3\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x14\n\x12\x44\x65stinationIPInput\"\x16\n\x14\x44\x65stinationPortInput\"\x0f\n\rSourceIPInput\"\x11\n\x0fSourcePortInput\"\x15\n\x13\x44irectSourceIPInput\"\x11\n\x0fSourceTypeInput\"\x11\n\x0fServerNameInput\"\x18\n\x16TransportProtocolInput\"\x1a\n\x18\x41pplicationProtocolInput\"(\n\x10\x46ilterStateInput\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42\xc5\x01\n@io.envoyproxy.envoy.extensions.matching.common_inputs.network.v3B\x12NetworkInputsProtoP\x01Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/matching/common_inputs/network/v3;networkv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.matching.common_inputs.network.v3.network_inputs_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n@io.envoyproxy.envoy.extensions.matching.common_inputs.network.v3B\022NetworkInputsProtoP\001Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/matching/common_inputs/network/v3;networkv3\272\200\310\321\006\002\020\002'
  _FILTERSTATEINPUT.fields_by_name['key']._options = None
  _FILTERSTATEINPUT.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_DESTINATIONIPINPUT']._serialized_start=183
  _globals['_DESTINATIONIPINPUT']._serialized_end=203
  _globals['_DESTINATIONPORTINPUT']._serialized_start=205
  _globals['_DESTINATIONPORTINPUT']._serialized_end=227
  _globals['_SOURCEIPINPUT']._serialized_start=229
  _globals['_SOURCEIPINPUT']._serialized_end=244
  _globals['_SOURCEPORTINPUT']._serialized_start=246
  _globals['_SOURCEPORTINPUT']._serialized_end=263
  _globals['_DIRECTSOURCEIPINPUT']._serialized_start=265
  _globals['_DIRECTSOURCEIPINPUT']._serialized_end=286
  _globals['_SOURCETYPEINPUT']._serialized_start=288
  _globals['_SOURCETYPEINPUT']._serialized_end=305
  _globals['_SERVERNAMEINPUT']._serialized_start=307
  _globals['_SERVERNAMEINPUT']._serialized_end=324
  _globals['_TRANSPORTPROTOCOLINPUT']._serialized_start=326
  _globals['_TRANSPORTPROTOCOLINPUT']._serialized_end=350
  _globals['_APPLICATIONPROTOCOLINPUT']._serialized_start=352
  _globals['_APPLICATIONPROTOCOLINPUT']._serialized_end=378
  _globals['_FILTERSTATEINPUT']._serialized_start=380
  _globals['_FILTERSTATEINPUT']._serialized_end=420
# @@protoc_insertion_point(module_scope)
