# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/health_check/v3/health_check.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@envoy/extensions/filters/http/health_check/v3/health_check.proto\x12-envoy.extensions.filters.http.health_check.v3\x1a,envoy/config/route/v3/route_components.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xdc\x03\n\x0bHealthCheck\x12?\n\x11pass_through_mode\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12-\n\ncache_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x85\x01\n\x1f\x63luster_min_healthy_percentages\x18\x04 \x03(\x0b\x32\\.envoy.extensions.filters.http.health_check.v3.HealthCheck.ClusterMinHealthyPercentagesEntry\x12\x35\n\x07headers\x18\x05 \x03(\x0b\x32$.envoy.config.route.v3.HeaderMatcher\x1a[\n!ClusterMinHealthyPercentagesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.envoy.type.v3.Percent:\x02\x38\x01:;\x9a\xc5\x88\x1e\x36\n4envoy.config.filter.http.health_check.v2.HealthCheckJ\x04\x08\x02\x10\x03\x42\xbe\x01\n;io.envoyproxy.envoy.extensions.filters.http.health_check.v3B\x10HealthCheckProtoP\x01Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/health_check/v3;health_checkv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.health_check.v3.health_check_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n;io.envoyproxy.envoy.extensions.filters.http.health_check.v3B\020HealthCheckProtoP\001Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/health_check/v3;health_checkv3\272\200\310\321\006\002\020\002'
  _HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY._options = None
  _HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY._serialized_options = b'8\001'
  _HEALTHCHECK.fields_by_name['pass_through_mode']._options = None
  _HEALTHCHECK.fields_by_name['pass_through_mode']._serialized_options = b'\372B\005\212\001\002\020\001'
  _HEALTHCHECK._options = None
  _HEALTHCHECK._serialized_options = b'\232\305\210\0366\n4envoy.config.filter.http.health_check.v2.HealthCheck'
  _globals['_HEALTHCHECK']._serialized_start=346
  _globals['_HEALTHCHECK']._serialized_end=822
  _globals['_HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY']._serialized_start=664
  _globals['_HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY']._serialized_end=755
# @@protoc_insertion_point(module_scope)
